cludes/admin/tools/repair.php:774
msgid "Nothing to remove!"
msgstr ""

#: includes/admin/tools/repair.php:667
msgid "Removing trashed topics from user subscriptions&hellip; %s"
msgstr ""

#: includes/admin/tools/repair.php:736
msgid "Removing trashed forums from user subscriptions&hellip; %s"
msgstr ""

#: includes/admin/tools/repair.php:803
msgid "Remapping forum role for each user on this site&hellip; %s"
msgstr ""

#: includes/admin/tools/repair.php:901
msgid "Complete! %s users updated."
msgstr ""

#: includes/admin/tools/repair.php:917
msgid "Recomputing latest post in every topic and forum&hellip; %s"
msgstr ""

#: includes/admin/tools/repair.php:1038
msgid "Repairing the sticky topic to the parent forum relationships&hellip; %s"
msgstr ""

#: includes/admin/tools/repair.php:1103
msgid "Repairing closed topics&hellip; %s"
msgstr ""

#: includes/admin/tools/repair.php:1104
msgid "No closed topics to repair."
msgstr ""

#: includes/admin/tools/repair.php:1134
msgid "Complete! %d closed topic repaired."
msgid_plural "Complete! %d closed topics repaired."
msgstr[0] ""
msgstr[1] ""

#: includes/admin/tools/repair.php:1147
msgid "Recalculating forum visibility&hellip; %s"
msgstr ""

#: includes/admin/tools/repair.php:1170
msgid "Recalculating the forum for each post&hellip; %s"
msgstr ""

#: includes/admin/tools/repair.php:1232
msgid "Recalculating the topic for each post&hellip; %s"
msgstr ""

#: includes/admin/tools/repair.php:1283
msgid "Recalculating reply menu order&hellip; %s"
msgstr ""

#: includes/admin/tools/repair.php:1284
msgid "No reply positions to recalculate."
msgstr ""

#: includes/admin/tools/reset.php:26
msgid ""
"Revert your forums back to a brand new installation, as if bbPress were "
"never installed. This process cannot be undone."
msgstr ""

#: includes/admin/tools/reset.php:32
msgid "The following data will be removed:"
msgstr ""

#: includes/admin/tools/reset.php:34 includes/forums/template.php:51
msgid "All Forums"
msgstr ""

#: includes/admin/tools/reset.php:35 includes/topics/functions.php:3774
#: includes/topics/template.php:50
msgid "All Topics"
msgstr ""

#: includes/admin/tools/reset.php:36 includes/replies/functions.php:2161
#: includes/replies/template.php:52
msgid "All Replies"
msgstr ""

#: includes/admin/tools/reset.php:37
msgid "All Topic Tags"
msgstr ""

#: includes/admin/tools/reset.php:38
msgid "All Meta Data"
msgstr ""

#: includes/admin/tools/reset.php:39
msgid "Forum Settings"
msgstr ""

#: includes/admin/tools/reset.php:40
msgid "Forum Activity"
msgstr ""

#: includes/admin/tools/reset.php:41
msgid "Forum User Roles"
msgstr ""

#: includes/admin/tools/reset.php:43
msgid "Importer Helper Data"
msgstr ""

#: includes/admin/tools/reset.php:47
msgid "Delete imported users?"
msgstr ""

#: includes/admin/tools/reset.php:50 includes/admin/tools/reset.php:60
msgid "Say it ain't so!"
msgstr ""

#: includes/admin/tools/reset.php:51
msgid "This option will delete all previously imported users, and cannot be undone."
msgstr ""

#: includes/admin/tools/reset.php:52
msgid ""
"Proceeding without this checked removes the meta-data necessary to delete "
"these users later."
msgstr ""

#: includes/admin/tools/reset.php:57
msgid "Do you really want to do this?"
msgstr ""

#: includes/admin/tools/reset.php:61
#: templates/default/bbpress/form-reply-move.php:76
#: templates/default/bbpress/form-topic-merge.php:98
#: templates/default/bbpress/form-topic-split.php:102
msgid "This process cannot be undone."
msgstr ""

#: includes/admin/tools/reset.php:62
msgid "Backup your database before proceeding."
msgstr ""

#: includes/admin/tools/reset.php:70
msgid "Reset bbPress"
msgstr ""

#: includes/admin/tools/reset.php:119
msgid "Resetting&hellip;"
msgstr ""

#: includes/admin/tools/reset.php:121
msgid "Success!"
msgstr ""

#: includes/admin/tools/reset.php:123
msgid "Skipped."
msgstr ""

#: includes/admin/tools/reset.php:182
msgid "Removing Forums, Topics, and Replies&hellip; %s"
msgstr ""

#: includes/admin/tools/reset.php:190
msgid "Removing Forum, Topic, and Reply Meta Data&hellip; %s"
msgstr ""

#: includes/admin/tools/reset.php:199
msgid "Removing Revision Data&hellip; %s"
msgstr ""

#: includes/admin/tools/reset.php:208
msgid "Deleting Topic Tags&hellip; %s"
msgstr ""

#: includes/admin/tools/reset.php:227
msgid "Deleting Imported Users&hellip; %s"
msgstr ""

#: includes/admin/tools/reset.php:233
msgid "Deleting Imported User Meta&hellip; %s"
msgstr ""

#: includes/admin/tools/reset.php:241
msgid "Deleting bbPress Specific User Meta&hellip; %s"
msgstr ""

#: includes/admin/tools/reset.php:250
msgid "Dropping Conversion Table&hellip; %s"
msgstr ""

#: includes/admin/tools/reset.php:257
msgid "Deleting Settings&hellip; Success!"
msgstr ""

#: includes/admin/tools/reset.php:263
msgid "Removing Roles and Capabilities&hellip; Success!"
msgstr ""

#: includes/admin/tools/upgrade.php:44
msgid ""
"As bbPress improves, occasionally database upgrades are required but some "
"forums are too large to upgrade automatically. Use the tools below to "
"manually run upgrade routines."
msgstr ""

#: includes/admin/tools/upgrade.php:45
msgid ""
"Some of these tools create substantial database overhead. Use caution when "
"running more than 1 upgrade at a time."
msgstr ""

#: includes/admin/tools/upgrade.php:95 includes/admin/tools/upgrade.php:137
#: includes/admin/tools/upgrade.php:182
msgid "Version"
msgstr ""

#: includes/admin/tools/upgrade.php:215
msgid "Upgrading user engagements&hellip; %s"
msgstr ""

#: includes/admin/tools/upgrade.php:216
msgid "No engagements to upgrade."
msgstr ""

#: includes/admin/tools/upgrade.php:249
msgid "Complete! %d engagement upgraded."
msgid_plural "Complete! %d engagements upgraded."
msgstr[0] ""
msgstr[1] ""

#: includes/admin/tools/upgrade.php:267
msgid "Upgrading BuddyPress group-forum relationships&hellip; %s"
msgstr ""

#: includes/admin/tools/upgrade.php:372
msgid "group-forums"
msgstr ""

#: includes/admin/tools/upgrade.php:388
msgid "Complete! %s groups updated; %s forums updated; %s forum statuses synced."
msgstr ""

#: includes/admin/tools/upgrade.php:403
msgid "Upgrading user favorites&hellip; %s"
msgstr ""

#: includes/admin/tools/upgrade.php:404
msgid "No favorites to upgrade."
msgstr ""

#: includes/admin/tools/upgrade.php:447
msgid "Complete! %d favorite upgraded."
msgid_plural "Complete! %d favorites upgraded."
msgstr[0] ""
msgstr[1] ""

#: includes/admin/tools/upgrade.php:463
msgid "Upgrading user topic subscriptions&hellip; %s"
msgstr ""

#: includes/admin/tools/upgrade.php:464
msgid "No topic subscriptions to upgrade."
msgstr ""

#: includes/admin/tools/upgrade.php:507
msgid "Complete! %d topic subscription upgraded."
msgid_plural "Complete! %d topic subscriptions upgraded."
msgstr[0] ""
msgstr[1] ""

#: includes/admin/tools/upgrade.php:523
msgid "Upgrading user forum subscriptions&hellip; %s"
msgstr ""

#: includes/admin/tools/upgrade.php:524
msgid "No forum subscriptions to upgrade."
msgstr ""

#: includes/admin/tools/upgrade.php:567
msgid "Complete! %d forum subscription upgraded."
msgid_plural "Complete! %d forum subscriptions upgraded."
msgstr[0] ""
msgstr[1] ""

#: includes/admin/tools/upgrade.php:583
msgid "Remove favorites from usermeta&hellip; %s"
msgstr ""

#: includes/admin/tools/upgrade.php:584
msgid "No favorites to remove."
msgstr ""

#: includes/admin/tools/upgrade.php:603
msgid "Complete! %d favorite deleted."
msgid_plural "Complete! %d favorites deleted."
msgstr[0] ""
msgstr[1] ""

#: includes/admin/tools/upgrade.php:619
msgid "Remove topic subscriptions from usermeta&hellip; %s"
msgstr ""

#: includes/admin/tools/upgrade.php:620
msgid "No topic subscriptions to remove."
msgstr ""

#: includes/admin/tools/upgrade.php:639
msgid "Complete! %d topic subscription deleted."
msgid_plural "Complete! %d topic subscriptions deleted."
msgstr[0] ""
msgstr[1] ""

#: includes/admin/tools/upgrade.php:655
msgid "Remove forum subscriptions from usermeta&hellip; %s"
msgstr ""

#: includes/admin/tools/upgrade.php:656
msgid "No forum subscriptions to remove."
msgstr ""

#: includes/admin/tools/upgrade.php:675
msgid "Complete! %d forum subscription deleted."
msgid_plural "Complete! %d forum subscriptions deleted."
msgstr[0] ""
msgstr[1] ""

#: includes/admin/tools.php:31
msgid "bbPress provides the following tools to help you manage your forums:"
msgstr ""

#: includes/admin/tools.php:78
msgid "The repair was completed successfully"
msgstr ""

#: includes/admin/tools.php:79
msgid "The repair was not successful"
msgstr ""

#: includes/admin/tools.php:115
msgid "Recalculate parent topic for each reply"
msgstr ""

#: includes/admin/tools.php:116
msgid "Run this if replies appear in the wrong topics."
msgstr ""

#: includes/admin/tools.php:127
msgid "Recalculate parent forum for each topic and reply"
msgstr ""

#: includes/admin/tools.php:128
msgid "Run this if topics or replies appear in the wrong forums."
msgstr ""

#: includes/admin/tools.php:139
msgid "Recalculate private and hidden forums"
msgstr ""

#: includes/admin/tools.php:140
msgid "Run this if non-public forums are publicly visible."
msgstr ""

#: includes/admin/tools.php:151
msgid "Recalculate last activity in each topic and forum"
msgstr ""

#: includes/admin/tools.php:152
msgid "Run this if freshness appears incorrectly."
msgstr ""

#: includes/admin/tools.php:163
msgid "Recalculate sticky relationship of each topic"
msgstr ""

#: includes/admin/tools.php:164
msgid "Run this if sticky topics appear incorrectly."
msgstr ""

#: includes/admin/tools.php:175
msgid "Recalculate position of each reply in each topic"
msgstr ""

#: includes/admin/tools.php:176
msgid "Run this if replies appear in the wrong order."
msgstr ""

#: includes/admin/tools.php:187
msgid "Recalculate engagements in each topic for each user"
msgstr ""

#: includes/admin/tools.php:188
msgid "Run this if voices appear incorrectly."
msgstr ""

#: includes/admin/tools.php:199
msgid "Repair closed topic statuses"
msgstr ""

#: includes/admin/tools.php:200
msgid "Run this if closed topics appear incorrectly."
msgstr ""

#: includes/admin/tools.php:211
msgid "Recount topics in each forum"
msgstr ""

#: includes/admin/tools.php:212
msgid "Run this if the number of topics in any forums are incorrect."
msgstr ""

#: includes/admin/tools.php:223
msgid "Recount topics in each topic-tag"
msgstr ""

#: includes/admin/tools.php:224
msgid "Run this if the number of topics in any topic-tags are incorrect."
msgstr ""

#: includes/admin/tools.php:235
msgid "Recount replies in each forum"
msgstr ""

#: includes/admin/tools.php:236
msgid "Run this if the number of replies in any forums are incorrect."
msgstr ""

#: includes/admin/tools.php:247
msgid "Recount pending, spammed, and trashed replies in each forum"
msgstr ""

#: includes/admin/tools.php:248
msgid "Run this if non-public replies display incorrectly in forums."
msgstr ""

#: includes/admin/tools.php:259
msgid "Recount replies in each topic"
msgstr ""

#: includes/admin/tools.php:260
msgid "Run this if the number of replies in any topics are incorrect."
msgstr ""

#: includes/admin/tools.php:271
msgid "Recount pending, spammed, and trashed replies in each topic"
msgstr ""

#: includes/admin/tools.php:272
msgid "Run this if non-public replies display incorrectly in topics."
msgstr ""

#: includes/admin/tools.php:283
msgid "Recount topics for each user"
msgstr ""

#: includes/admin/tools.php:284
msgid "Run this to get fresh topic counts for all users."
msgstr ""

#: includes/admin/tools.php:295
msgid "Recount replies for each user"
msgstr ""

#: includes/admin/tools.php:296
msgid "Run this to get fresh reply counts for all users."
msgstr ""

#: includes/admin/tools.php:307
msgid "Remove unpublished topics from user favorites"
msgstr ""

#: includes/admin/tools.php:308
msgid "Run this to remove trashed or deleted topics from all user favorites."
msgstr ""

#: includes/admin/tools.php:319
msgid "Remove unpublished topics from user subscriptions"
msgstr ""

#: includes/admin/tools.php:320
msgid "Run this to remove trashed or deleted topics from all user subscriptions."
msgstr ""

#: includes/admin/tools.php:331
msgid "Remove unpublished forums from user subscriptions"
msgstr ""

#: includes/admin/tools.php:332
msgid "Run this to remove trashed or deleted forums from all user subscriptions."
msgstr ""

#: includes/admin/tools.php:343
msgid "Remap all users to default forum roles"
msgstr ""

#: includes/admin/tools.php:344
msgid "Run this if users have issues accessing the forums."
msgstr ""

#: includes/admin/tools.php:355
msgid "Upgrade user topic engagements"
msgstr ""

#: includes/admin/tools.php:356
msgid "Copies engagements from user meta to topic meta."
msgstr ""

#: includes/admin/tools.php:368
msgid "Upgrade user topic favorites"
msgstr ""

#: includes/admin/tools.php:369
msgid "Copies favorites from user meta to topic meta."
msgstr ""

#: includes/admin/tools.php:381
msgid "Upgrade user topic subscriptions"
msgstr ""

#: includes/admin/tools.php:382
msgid "Copies topic subscriptions from user meta to topic meta."
msgstr ""

#: includes/admin/tools.php:394
msgid "Upgrade user forum subscriptions"
msgstr ""

#: includes/admin/tools.php:395
msgid "Copies forum subscriptions from user meta to forum meta."
msgstr ""

#: includes/admin/tools.php:407
msgid "Remove favorites from user-meta"
msgstr ""

#: includes/admin/tools.php:408
msgid "Run this to delete old data (after confirming successful favorites upgrade)"
msgstr ""

#: includes/admin/tools.php:420
msgid "Remove topic subscriptions from user-meta"
msgstr ""

#: includes/admin/tools.php:421
msgid ""
"Run this to delete old data (after confirming successful topic "
"subscriptions upgrade)"
msgstr ""

#: includes/admin/tools.php:433
msgid "Remove forum subscriptions from user-meta"
msgstr ""

#: includes/admin/tools.php:434
msgid ""
"Run this to delete old data (after confirming successful forum "
"subscriptions upgrade)"
msgstr ""

#: includes/admin/tools.php:446
msgid "Upgrade BuddyPress Group Forum relationships"
msgstr ""

#: includes/admin/tools.php:447
msgid "Run this if you just upgraded BuddyPress Forums from Legacy."
msgstr ""

#: includes/admin/tools.php:450
msgid "Any"
msgstr ""

#: includes/admin/tools.php:532
msgid "Upgrade Forums"
msgstr ""

#: includes/admin/tools.php:541
msgid "Import Forums"
msgstr ""

#: includes/admin/topics.php:121
msgid ""
"This screen displays the individual topics on your site. You can customize "
"the display of this screen to suit your workflow."
msgstr ""

#: includes/admin/topics.php:131
msgid ""
"You can hide/display columns based on your needs and decide how many topics "
"to list per screen using the Screen Options tab."
msgstr ""

#: includes/admin/topics.php:132
msgid ""
"You can filter the list of topics by topic status using the text links in "
"the upper left to show All, Published, Draft, Pending, Trashed, Closed, or "
"Spam  topics. The default view is to show all topics."
msgstr ""

#: includes/admin/topics.php:133
msgid ""
"You can view topics in a simple title list or with an excerpt. Choose the "
"view you prefer by clicking on the icons at the top of the list on the "
"right."
msgstr ""

#: includes/admin/topics.php:134
msgid ""
"You can refine the list to show only topics in a specific forum or from a "
"specific month by using the dropdown menus above the topics list. Click the "
"Filter button after making your selection."
msgstr ""

#: includes/admin/topics.php:143
msgid ""
"Hovering over a row in the topics list will display action links that allow "
"you to manage your topic. You can perform the following actions:"
msgstr ""

#: includes/admin/topics.php:145
msgid ""
"<strong>Edit</strong> takes you to the editing screen for that topic. You "
"can also reach that screen by clicking on the topic title."
msgstr ""

#: includes/admin/topics.php:146
msgid ""
"<strong>Stick</strong> will keep the selected topic &#8217;pinned&#8217; to "
"the top the parent forum topic list."
msgstr ""

#: includes/admin/topics.php:147
msgid ""
"<strong>Stick <em>(to front)</em></strong> will keep the selected topic "
"&#8217;pinned&#8217; to the top of ALL forums and be visable in any forums "
"topics list."
msgstr ""

#: includes/admin/topics.php:149
msgid ""
"<strong>Close</strong> will mark the selected topic as &#8217;closed&#8217; "
"and disable the ability to post new replies to it."
msgstr ""

#: includes/admin/topics.php:150
msgid ""
"<strong>Spam</strong> removes your topic from this list and places it in "
"the spam queue, from which you can permanently delete it."
msgstr ""

#: includes/admin/topics.php:151
msgid ""
"<strong>Trash</strong> removes your topic from this list and places it in "
"the trash, from which you can permanently delete it."
msgstr ""

#: includes/admin/topics.php:152
msgid "<strong>View</strong> will take you to your live site to view the topic."
msgstr ""

#: includes/admin/topics.php:161
msgid ""
"You can also edit, spam, or move multiple topics to the trash at once. "
"Select the topics you want to act on using the checkboxes, then select the "
"action you want to take from the Bulk Actions menu and click Apply."
msgstr ""

#: includes/admin/topics.php:162
msgid ""
"When using Bulk Edit, you can change the metadata (categories, author, "
"etc.) for all selected topics at once. To remove a topic from the grouping, "
"just click the x next to its name in the Bulk Edit area that appears."
msgstr ""

#: includes/admin/topics.php:180
msgid ""
"The title field and the big topic editing Area are fixed in place, but you "
"can reposition all the other boxes using drag and drop, and can minimize or "
"expand them by clicking the title bar of each box. Use the Screen Options "
"tab to unhide more boxes (Excerpt, Send Trackbacks, Custom Fields, "
"Discussion, Slug, Author) or to choose a 1- or 2-column layout for this "
"screen."
msgstr ""

#: includes/admin/topics.php:190
msgid "Title and Topic Editor"
msgstr ""

#: includes/admin/topics.php:192
msgid ""
"<strong>Title</strong> - Enter a title for your topic. After you enter a "
"title, you&#8217;ll see the permalink below, which you can edit."
msgstr ""

#: includes/admin/topics.php:193
msgid ""
"<strong>Topic Editor</strong> - Enter the text for your topic. There are "
"two modes of editing: Visual and HTML. Choose the mode by clicking on the "
"appropriate tab. Visual mode gives you a WYSIWYG editor. Click the last "
"icon in the row to get a second row of controls. The HTML mode allows you "
"to enter raw HTML along with your topic text. You can insert media files by "
"clicking the icons above the topic editor and following the directions. You "
"can go to the distraction-free writing screen via the Fullscreen icon in "
"Visual mode (second to last in the top row) or the Fullscreen button in "
"HTML mode (last in the row). Once there, you can make buttons visible by "
"hovering over the top area. Exit Fullscreen back to the regular topic "
"editor."
msgstr ""

#: includes/admin/topics.php:196
msgid ""
"<strong>Publish</strong> - You can set the terms of publishing your topic "
"in the Publish box. For Status, Visibility, and Publish (immediately), "
"click on the Edit link to reveal more options. Visibility includes options "
"for password-protecting a topic or making it stay at the top of your blog "
"indefinitely (sticky). Publish (immediately) allows you to set a future or "
"past date and time, so you can schedule a topic to be published in the "
"future or backdate a topic."
msgstr ""

#: includes/admin/topics.php:199
msgid ""
"<strong>Featured Image</strong> - This allows you to associate an image "
"with your topic without inserting it. This is usually useful only if your "
"theme makes use of the featured image as a topic thumbnail on the home "
"page, a custom header, etc."
msgstr ""

#: includes/admin/topics.php:204 includes/admin/topics.php:341
#: includes/topics/template.php:67
msgid "Topic Attributes"
msgstr ""

#: includes/admin/topics.php:206
msgid "Select the attributes that your topic should have:"
msgstr ""

#: includes/admin/topics.php:208
msgid ""
"<strong>Forum</strong> dropdown determines the parent forum that the topic "
"belongs to. Select the forum or category from the dropdown, or leave the "
"default \"No forum\" to post the topic without an assigned forum."
msgstr ""

#: includes/admin/topics.php:209
msgid ""
"<strong>Topic Type</strong> dropdown indicates the sticky status of the "
"topic. Selecting the super sticky option would stick the topic to the front "
"of your forums, i.e. the topic index, sticky option would stick the topic "
"to its respective forum. Selecting normal would not stick the topic "
"anywhere."
msgstr ""

#: includes/admin/topics.php:256
msgid "%s topic updated."
msgid_plural "%s topics updated."
msgstr[0] ""
msgstr[1] ""

#: includes/admin/topics.php:258
msgid "1 topic not updated, somebody is editing it."
msgstr ""

#: includes/admin/topics.php:259
msgid "%s topic not updated, somebody is editing it."
msgid_plural "%s topics not updated, somebody is editing them."
msgstr[0] ""
msgstr[1] ""

#: includes/admin/topics.php:292
msgid "Error in spamming topic."
msgstr ""

#: includes/admin/topics.php:308
msgid "Sorry, you are not allowed to unspam this topic."
msgstr ""

#: includes/admin/topics.php:317
msgid "Error in unspamming topic."
msgstr ""

#: includes/admin/topics.php:577
msgid "The topic was not found."
msgstr ""

#: includes/admin/topics.php:713
msgid "There was a problem opening the topic \"%1$s\"."
msgstr ""

#: includes/admin/topics.php:714
msgid "Topic \"%1$s\" successfully opened."
msgstr ""

#: includes/admin/topics.php:719
msgid "There was a problem closing the topic \"%1$s\"."
msgstr ""

#: includes/admin/topics.php:720
msgid "Topic \"%1$s\" successfully closed."
msgstr ""

#: includes/admin/topics.php:725
msgid "There was a problem sticking the topic \"%1$s\" to front."
msgstr ""

#: includes/admin/topics.php:726
msgid "Topic \"%1$s\" successfully stuck to front."
msgstr ""

#: includes/admin/topics.php:731
msgid "There was a problem sticking the topic \"%1$s\"."
msgstr ""

#: includes/admin/topics.php:732
msgid "Topic \"%1$s\" successfully stuck."
msgstr ""

#: includes/admin/topics.php:737
msgid "There was a problem unsticking the topic \"%1$s\"."
msgstr ""

#: includes/admin/topics.php:738
msgid "Topic \"%1$s\" successfully unstuck."
msgstr ""

#: includes/admin/topics.php:743
msgid "There was a problem marking the topic \"%1$s\" as spam."
msgstr ""

#: includes/admin/topics.php:744
msgid "Topic \"%1$s\" successfully marked as spam."
msgstr ""

#: includes/admin/topics.php:749
msgid "There was a problem unmarking the topic \"%1$s\" as spam."
msgstr ""

#: includes/admin/topics.php:750
msgid "Topic \"%1$s\" successfully unmarked as spam."
msgstr ""

#: includes/admin/topics.php:755
msgid "There was a problem approving the topic \"%1$s\"."
msgstr ""

#: includes/admin/topics.php:756
msgid "Topic \"%1$s\" successfully approved."
msgstr ""

#: includes/admin/topics.php:761
msgid "There was a problem unapproving the topic \"%1$s\"."
msgstr ""

#: includes/admin/topics.php:762
msgid "Topic \"%1$s\" successfully unapproved."
msgstr ""

#: includes/admin/topics.php:857 templates/default/bbpress/loop-topics.php:19
msgid "Voices"
msgstr ""

#: includes/admin/topics.php:935 includes/topics/template.php:1983
msgid "No Replies"
msgstr ""

#: includes/admin/topics.php:985
msgid "Unapprove this topic"
msgstr ""

#: includes/admin/topics.php:990
msgid "Approve this topic"
msgstr ""

#: includes/admin/topics.php:1002
msgid "Close this topic"
msgstr ""

#: includes/admin/topics.php:1004
msgid "Open this topic"
msgstr ""

#: includes/admin/topics.php:1013
msgid "Unstick this topic"
msgstr ""

#: includes/admin/topics.php:1013 includes/topics/template.php:2684
msgid "Unstick"
msgstr ""

#: includes/admin/topics.php:1016
msgid "Stick this topic to its forum"
msgstr ""

#: includes/admin/topics.php:1016 includes/topics/template.php:2683
msgid "Stick"
msgstr ""

#: includes/admin/topics.php:1016
msgid "Stick this topic to front"
msgstr ""

#: includes/admin/topics.php:1016 includes/topics/template.php:2685
msgid "(to front)"
msgstr ""

#: includes/admin/topics.php:1023
msgid "Mark this topic as spam"
msgstr ""

#: includes/admin/topics.php:1025
msgid "Mark the topic as not spam"
msgstr ""

#: includes/admin/topics.php:1175 includes/admin/topics.php:1187
#: includes/topics/template.php:78
msgid "Topic updated."
msgstr ""

#: includes/admin/topics.php:1192
#. translators: %s: date and time of the revision
msgid "Topic restored to revision from %s"
msgstr ""

#: includes/admin/topics.php:1198
msgid "Topic created."
msgstr ""

#: includes/admin/topics.php:1204
msgid "Topic saved."
msgstr ""

#: includes/admin/topics.php:1209
msgid "Topic submitted."
msgstr ""

#: includes/admin/topics.php:1218
msgid "Topic scheduled for: %s."
msgstr ""

#: includes/admin/topics.php:1229
msgid "Topic draft updated."
msgstr ""

#: includes/admin/users.php:98 includes/admin/users.php:282
#: includes/users/signups.php:30
#: templates/default/bbpress/form-user-roles.php:23
msgid "Forum Role"
msgstr ""

#: includes/admin/users.php:107 includes/admin/users.php:111
#: includes/users/template.php:1579
msgid "&mdash; No role for these forums &mdash;"
msgstr ""

#: includes/admin/users.php:164 includes/admin/users.php:166
msgid "Change forum role to&hellip;"
msgstr ""

#: includes/admin/users.php:170
msgid "Change"
msgstr ""

#: includes/admin/users.php:278
msgid "Site Role"
msgstr ""

#: includes/common/formatting.php:646
msgid "sometime"
msgstr ""

#: includes/common/formatting.php:647
msgid "right now"
msgstr ""

#: includes/common/formatting.php:648
msgid "%s ago"
msgstr ""

#: includes/common/formatting.php:652
msgid "%s year"
msgid_plural "%s years"
msgstr[0] ""
msgstr[1] ""

#: includes/common/formatting.php:653
msgid "%s month"
msgid_plural "%s months"
msgstr[0] ""
msgstr[1] ""

#: includes/common/formatting.php:654
msgid "%s week"
msgid_plural "%s weeks"
msgstr[0] ""
msgstr[1] ""

#: includes/common/formatting.php:655
msgid "%s day"
msgid_plural "%s days"
msgstr[0] ""
msgstr[1] ""

#: includes/common/formatting.php:656
msgid "%s hour"
msgid_plural "%s hours"
msgstr[0] ""
msgstr[1] ""

#: includes/common/formatting.php:657
msgid "%s minute"
msgid_plural "%s minutes"
msgstr[0] ""
msgstr[1] ""

#: includes/common/formatting.php:658
msgid "%s second"
msgid_plural "%s seconds"
msgstr[0] ""
msgstr[1] ""

#: includes/common/functions.php:442 includes/common/functions.php:491
msgid "Pending: %s"
msgstr ""

#: includes/common/functions.php:448 includes/common/functions.php:497
msgid "Private: %s"
msgstr ""

#: includes/common/functions.php:454 includes/common/functions.php:503
msgid "Hidden: %s"
msgstr ""

#: includes/common/functions.php:460 includes/common/functions.php:509
msgid "Spammed: %s"
msgstr ""

#: includes/common/functions.php:466 includes/common/functions.php:515
msgid "Trashed: %s"
msgstr ""

#: includes/common/functions.php:604
msgid "<strong>Error</strong>: Invalid author name."
msgstr ""

#: includes/common/functions.php:610
msgid "<strong>Error</strong>: Invalid email address."
msgstr ""

#: includes/common/functions.php:1149
msgid ""
"%1$s wrote:\n"
"\n"
"%2$s\n"
"\n"
"Post Link: %3$s\n"
"\n"
"-----------\n"
"\n"
"You are receiving this email because you subscribed to a forum topic.\n"
"\n"
"Login and visit the topic to unsubscribe from these emails."
msgstr ""

#: includes/common/functions.php:1316
msgid ""
"%1$s wrote:\n"
"\n"
"%2$s\n"
"\n"
"Topic Link: %3$s\n"
"\n"
"-----------\n"
"\n"
"You are receiving this email because you subscribed to a forum.\n"
"\n"
"Login and visit the topic to unsubscribe from these emails."
msgstr ""

#: includes/common/template.php:1196
msgid ""
"Conditional query tags do not work before the query is run. Before then, "
"they always return false."
msgstr ""

#: includes/common/template.php:1668
msgid "No topics available"
msgstr ""

#: includes/common/template.php:1673
msgid "No forums available"
msgstr ""

#: includes/common/template.php:1678
msgid "None available"
msgstr ""

#: includes/common/template.php:2292
msgid "Home"
msgstr ""

#: includes/common/template.php:2362
msgid "(Edit)"
msgstr ""

#: includes/common/template.php:2366 includes/common/template.php:2481
#: includes/common/template.php:2726 includes/core/theme-compat.php:804
#: templates/default/extras/taxonomy-topic-tag-edit.php:17
#: templates/default/extras/taxonomy-topic-tag.php:17
msgid "Topic Tag: %s"
msgstr ""

#: includes/common/template.php:2387
msgid "&lsaquo;"
msgstr ""

#: includes/common/template.php:2387
msgid "&rsaquo;"
msgstr ""

#: includes/common/template.php:2650
msgid "Log Out"
msgstr ""

#: includes/common/template.php:2690
msgid "Forum Edit: %s"
msgstr ""

#: includes/common/template.php:2695
msgid "Topic Edit: %s"
msgstr ""

#: includes/common/template.php:2700
msgid "Reply Edit: %s"
msgstr ""

#: includes/common/template.php:2705
msgid "Topic Tag Edit: %s"
msgstr ""

#: includes/common/template.php:2712
msgid "Forum: %s"
msgstr ""

#: includes/common/template.php:2717
msgid "Topic: %s"
msgstr ""

#: includes/common/template.php:2739
msgid "Your Topics"
msgstr ""

#: includes/common/template.php:2743
#. translators: user's display name
msgid "%s's Topics"
msgstr ""

#: includes/common/template.php:2749
msgid "Your Replies"
msgstr ""

#: includes/common/template.php:2753
#. translators: user's display name
msgid "%s's Replies"
msgstr ""

#: includes/common/template.php:2759
msgid "Your Favorites"
msgstr ""

#: includes/common/template.php:2763
#: templates/default/bbpress/user-details.php:57
#. translators: user's display name
msgid "%s's Favorites"
msgstr ""

#: includes/common/template.php:2769
msgid "Your Subscriptions"
msgstr ""

#: includes/common/template.php:2773
#: templates/default/bbpress/user-details.php:67
#. translators: user's display name
msgid "%s's Subscriptions"
msgstr ""

#: includes/common/template.php:2779
msgid "Your Profile"
msgstr ""

#: includes/common/template.php:2783
#: templates/default/bbpress/user-details.php:30
#. translators: user's display name
msgid "%s's Profile"
msgstr ""

#: includes/common/template.php:2792
msgid "Edit Your Profile"
msgstr ""

#: includes/common/template.php:2797
#: templates/default/bbpress/user-details.php:74
msgid "Edit %s's Profile"
msgstr ""

#: includes/common/template.php:2805
msgid "View: %s"
msgstr ""

#: includes/common/widgets.php:34
msgid "A simple login form with optional links to sign-up and lost password pages."
msgstr ""

#: includes/common/widgets.php:38
msgid "(bbPress) Login Widget"
msgstr ""

#: includes/common/widgets.php:81 includes/common/widgets.php:102
#: templates/default/bbpress/form-user-login.php:17
#: templates/default/bbpress/form-user-login.php:38
msgid "Log In"
msgstr ""

#: includes/common/widgets.php:84
#: templates/default/bbpress/form-user-edit.php:107
#: templates/default/bbpress/form-user-login.php:20
#: templates/default/bbpress/form-user-register.php:29
msgid "Username"
msgstr ""

#: includes/common/widgets.php:89
#: templates/default/bbpress/form-user-login.php:25
#: templates/default/bbpress/form-user-passwords.php:17
msgid "Password"
msgstr ""

#: includes/common/widgets.php:95
#: templates/default/bbpress/form-user-login.php:31
msgid "Keep me signed in"
msgstr ""

#: includes/common/widgets.php:114
#: templates/default/bbpress/form-user-register.php:42
msgid "Register"
msgstr ""

#: includes/common/widgets.php:120
#: templates/default/bbpress/form-user-lost-pass.php:17
msgid "Lost Password"
msgstr ""

#: includes/common/widgets.php:175 includes/common/widgets.php:320
#: includes/common/widgets.php:437 includes/common/widgets.php:599
#: includes/common/widgets.php:871 includes/common/widgets.php:1015
#: includes/common/widgets.php:1218
msgid "Title:"
msgstr ""

#: includes/common/widgets.php:180
msgid "Register URI:"
msgstr ""

#: includes/common/widgets.php:185
msgid "Lost Password URI:"
msgstr ""

#: includes/common/widgets.php:227
msgid "A list of registered optional topic views."
msgstr ""

#: includes/common/widgets.php:231
msgid "(bbPress) Topic Views List"
msgstr ""

#: includes/common/widgets.php:361
msgid "The bbPress forum search form."
msgstr ""

#: includes/common/widgets.php:365
msgid "(bbPress) Forum Search Form"
msgstr ""

#: includes/common/widgets.php:454 includes/forums/template.php:60
msgid "Search Forums"
msgstr ""

#: includes/common/widgets.php:478
msgid "A list of forums with an option to set the parent."
msgstr ""

#: includes/common/widgets.php:482
msgid "(bbPress) Forums List"
msgstr ""

#: includes/common/widgets.php:605 includes/common/widgets.php:875
msgid "Parent Forum ID:"
msgstr ""

#: includes/common/widgets.php:611 includes/common/widgets.php:881
msgid "\"0\" to show only root - \"any\" to show all"
msgstr ""

#: includes/common/widgets.php:651
msgid "A list of recent topics, sorted by: newness, popularity, or recent replies."
msgstr ""

#: includes/common/widgets.php:655
msgid "(bbPress) Recent Topics"
msgstr ""

#: includes/common/widgets.php:872
msgid "Maximum topics to show:"
msgstr ""

#: includes/common/widgets.php:884 includes/common/widgets.php:1220
msgid "Show post date:"
msgstr ""

#: includes/common/widgets.php:885
msgid "Show topic author:"
msgstr ""

#: includes/common/widgets.php:888
msgid "Order By:"
msgstr ""

#: includes/common/widgets.php:890
msgid "Newest Topics"
msgstr ""

#: includes/common/widgets.php:891
#: templates/default/extras/page-forum-statistics.php:34
msgid "Popular Topics"
msgstr ""

#: includes/common/widgets.php:892
msgid "Topics With Recent Replies"
msgstr ""

#: includes/common/widgets.php:908
msgid "Recent Topics"
msgstr ""

#: includes/common/widgets.php:937
msgid "Some statistics from your forum."
msgstr ""

#: includes/common/widgets.php:941
msgid "(bbPress) Statistics"
msgstr ""

#: includes/common/widgets.php:1032
msgid "Forum Statistics"
msgstr ""

#: includes/common/widgets.php:1056
msgid "A list of the most recent replies."
msgstr ""

#: includes/common/widgets.php:1060
msgid "(bbPress) Recent Replies"
msgstr ""

#: includes/common/widgets.php:1219
msgid "Maximum replies to show:"
msgstr ""

#: includes/common/widgets.php:1221
msgid "Show reply author:"
msgstr ""

#: includes/common/widgets.php:1235
msgid "Recent Replies"
msgstr ""

#: includes/core/capabilities.php:511
msgid "Editable forum roles no longer exist."
msgstr ""

#: includes/core/update.php:207
msgid "General"
msgstr ""

#: includes/core/update.php:208
msgid "General Discussion"
msgstr ""

#: includes/core/update.php:211
msgid "Hello World!"
msgstr ""

#: includes/core/update.php:212
msgid "This is the very first topic in these forums."
msgstr ""

#: includes/core/update.php:215
msgid "And this is the very first reply."
msgstr ""

#: includes/extend/akismet.php:373
#. translators: %s: reporter name
msgid "%s reported this topic as spam"
msgstr ""

#: includes/extend/akismet.php:378
#. translators: %s: reporter name
msgid "%s reported this reply as spam"
msgstr ""

#: includes/extend/akismet.php:383
#. translators: 1: reporter name, 2: comment type
msgid "%1$s reported this %2$s as spam"
msgstr ""

#: includes/extend/akismet.php:398
#. translators: %s: reporter name
msgid "%s reported this topic as not spam"
msgstr ""

#: includes/extend/akismet.php:403
#. translators: %s: reporter name
msgid "%s reported this reply as not spam"
msgstr ""

#: includes/extend/akismet.php:408
#. translators: 1: reporter name, 2: comment type
msgid "%1$s reported this %2$s as not spam"
msgstr ""

#: includes/extend/akismet.php:518 includes/extend/akismet.php:523
msgid "No response"
msgstr ""

#: includes/extend/akismet.php:604
msgid "Akismet caught this post as spam"
msgstr ""

#: includes/extend/akismet.php:613 includes/extend/akismet.php:636
msgid "Post status was changed to %s"
msgstr ""

#: includes/extend/akismet.php:627
msgid "Akismet cleared this post as not spam"
msgstr ""

#: includes/extend/akismet.php:650
msgid ""
"Akismet was unable to check this post (response: %s), will automatically "
"retry again later."
msgstr ""

#: includes/extend/akismet.php:914 includes/extend/akismet.php:924
msgid "Akismet History"
msgstr ""

#: includes/extend/akismet.php:968
msgid "No recorded history. Akismet has not checked this post."
msgstr ""

#: includes/extend/buddypress/activity.php:186
msgid "New forum topic"
msgstr ""

#: includes/extend/buddypress/activity.php:196
msgid "New forum reply"
msgstr ""

#: includes/extend/buddypress/activity.php:401
#: includes/extend/buddypress/functions.php:779
msgid "%1$s started the topic %2$s in the forum %3$s"
msgstr ""

#: includes/extend/buddypress/activity.php:539
#: includes/extend/buddypress/functions.php:780
msgid "%1$s replied to the topic %2$s in the forum %3$s"
msgstr ""

#: includes/extend/buddypress/groups.php:380
msgid "<strong>Error</strong>: Forum ID is invalid."
msgstr ""

#: includes/extend/buddypress/groups.php:443
msgid "<strong>Error</strong>: Reply To is invalid."
msgstr ""

#: includes/extend/buddypress/groups.php:468
#: includes/extend/buddypress/groups.php:471
msgid "Group Forum Settings"
msgstr ""

#: includes/extend/buddypress/groups.php:472
#: includes/extend/buddypress/groups.php:671
msgid ""
"Create a discussion forum to allow members of this group to communicate in "
"a structured, bulletin-board style fashion."
msgstr ""

#: includes/extend/buddypress/groups.php:476
#: includes/extend/buddypress/groups.php:674
msgid "Yes. I want this group to have a forum."
msgstr ""

#: includes/extend/buddypress/groups.php:479
msgid "Saying no will not delete existing forum content."
msgstr ""

#: includes/extend/buddypress/groups.php:484
msgid "Group Forum:"
msgstr ""

#: includes/extend/buddypress/groups.php:492
msgid "Network administrators can reconfigure which forum belongs to this group."
msgstr ""

#: includes/extend/buddypress/groups.php:497
msgid "Save Settings"
msgstr ""

#: includes/extend/buddypress/groups.php:532
#: includes/extend/buddypress/groups.php:689
#: includes/extend/buddypress/notifications.php:199
#: includes/forums/functions.php:126 includes/forums/functions.php:404
#: includes/replies/functions.php:134 includes/replies/functions.php:534
#: includes/replies/functions.php:1263 includes/topics/functions.php:105
#: includes/topics/functions.php:483 includes/topics/functions.php:1109
#: includes/topics/functions.php:1384 includes/topics/functions.php:1720
#: includes/topics/functions.php:1764 includes/topics/functions.php:1825
#: includes/users/engagements.php:612 includes/users/engagements.php:853
#: includes/users/functions.php:196 includes/users/functions.php:202
#: includes/users/functions.php:380
msgid "<strong>Error</strong>: Are you sure you wanted to do that?"
msgstr ""

#: includes/extend/buddypress/groups.php:669
msgid "Group Forum"
msgstr ""

#: includes/extend/buddypress/groups.php:1053
msgid "This group does not currently have a forum."
msgstr ""

#: includes/extend/buddypress/loader.php:137
msgid "Search Forums..."
msgstr ""

#: includes/extend/buddypress/loader.php:374
#: templates/default/bbpress/user-subscriptions.php:38
msgid "Subscribed Topics"
msgstr ""

#: includes/extend/buddypress/notifications.php:89
msgid "You have %1$d new replies to %2$s"
msgstr ""

#: includes/extend/buddypress/notifications.php:95
msgid "You have %1$d new reply to %2$s from %3$s"
msgstr ""

#: includes/extend/buddypress/notifications.php:96
msgid "You have %1$d new reply to %2$s"
msgstr ""

#: includes/extend/buddypress/notifications.php:101
msgid "Topic Replies"
msgstr ""

#: includes/extend/buddypress/notifications.php:203
msgid ""
"<strong>Error</strong>: You do not have permission to mark notifications "
"for that user."
msgstr ""

#: includes/forums/functions.php:140
msgid "<strong>Error</strong>: You do not have permission to create new forums."
msgstr ""

#: includes/forums/functions.php:165 includes/forums/functions.php:468
msgid "<strong>Error</strong>: Your forum needs a title."
msgstr ""

#: includes/forums/functions.php:170 includes/forums/functions.php:473
#: includes/replies/functions.php:284 includes/replies/functions.php:618
#: includes/topics/functions.php:163 includes/topics/functions.php:550
msgid "<strong>Error</strong>: Your title is too long."
msgstr ""

#: includes/forums/functions.php:184 includes/forums/functions.php:487
msgid "<strong>Error</strong>: Your forum description cannot be empty."
msgstr ""

#: includes/forums/functions.php:199
msgid "<strong>Error</strong>: Your forum must have a parent."
msgstr ""

#: includes/forums/functions.php:206
msgid ""
"<strong>Error</strong>: This forum is a category. No forums can be created "
"in this forum."
msgstr ""

#: includes/forums/functions.php:211 includes/forums/functions.php:443
msgid "<strong>Error</strong>: This forum has been closed to new forums."
msgstr ""

#: includes/forums/functions.php:216 includes/forums/functions.php:448
msgid ""
"<strong>Error</strong>: This forum is private and you do not have the "
"capability to read or create new forums in it."
msgstr ""

#: includes/forums/functions.php:221 includes/forums/functions.php:453
msgid ""
"<strong>Error</strong>: This forum is hidden and you do not have the "
"capability to read or create new forums in it."
msgstr ""

#: includes/forums/functions.php:228 includes/replies/functions.php:304
#: includes/topics/functions.php:247
msgid "<strong>Error</strong>: Slow down; you move too fast."
msgstr ""

#: includes/forums/functions.php:242
msgid "<strong>Error</strong>: This forum already exists."
msgstr ""

#: includes/forums/functions.php:248
msgid "<strong>Error</strong>: Your forum cannot be created at this time."
msgstr ""

#: includes/forums/functions.php:364 includes/replies/functions.php:491
#: includes/topics/functions.php:415
msgid "<strong>Error</strong>: The following problem(s) occurred: %s"
msgstr ""

#: includes/forums/functions.php:368
msgid "<strong>Error</strong>: The forum was not created."
msgstr ""

#: includes/forums/functions.php:393
msgid "<strong>Error</strong>: Forum ID not found."
msgstr ""

#: includes/forums/functions.php:409
msgid "<strong>Error</strong>: The forum you want to edit was not found."
msgstr ""

#: includes/forums/functions.php:414
msgid "<strong>Error</strong>: You do not have permission to edit that forum."
msgstr ""

#: includes/forums/functions.php:493
msgid "<strong>Error</strong>: Your forum cannot be edited at this time."
msgstr ""

#: includes/forums/template.php:52 includes/replies/template.php:53
#: includes/topics/template.php:51
msgid "Add New"
msgstr ""

#: includes/forums/template.php:53 templates/default/bbpress/form-forum.php:40
msgid "Create New Forum"
msgstr ""

#: includes/forums/template.php:55
msgid "Edit Forum"
msgstr ""

#: includes/forums/template.php:56
msgid "New Forum"
msgstr ""

#: includes/forums/template.php:57 includes/forums/template.php:58
msgid "View Forum"
msgstr ""

#: includes/forums/template.php:59
msgid "View Forums"
msgstr ""

#: includes/forums/template.php:61
msgid "No forums found"
msgstr ""

#: includes/forums/template.php:62
msgid "No forums found in Trash"
msgstr ""

#: includes/forums/template.php:63
msgid "Filter forums list"
msgstr ""

#: includes/forums/template.php:64
msgid "Forums list"
msgstr ""

#: includes/forums/template.php:65
msgid "Forums list navigation"
msgstr ""

#: includes/forums/template.php:66 templates/default/bbpress/form-forum.php:132
msgid "Parent Forum:"
msgstr ""

#: includes/forums/template.php:69
msgid "Insert into forum"
msgstr ""

#: includes/forums/template.php:70
msgid "Uploaded to this forum"
msgstr ""

#: includes/forums/template.php:71
msgid "Forum Image"
msgstr ""

#: includes/forums/template.php:72
msgid "Set forum image"
msgstr ""

#: includes/forums/template.php:73
msgid "Remove forum image"
msgstr ""

#: includes/forums/template.php:74
msgid "Use as forum image"
msgstr ""

#: includes/forums/template.php:75
msgid "Forum published."
msgstr ""

#: includes/forums/template.php:76
msgid "Forum published privately."
msgstr ""

#: includes/forums/template.php:77
msgid "Forum reverted to draft."
msgstr ""

#: includes/forums/template.php:78
msgid "Forum scheduled."
msgstr ""

#: includes/forums/template.php:833 includes/topics/template.php:1776
#: includes/users/template.php:1311
msgid "Subscribe"
msgstr ""

#: includes/forums/template.php:834 includes/topics/template.php:1777
#: includes/users/template.php:1312
msgid "Unsubscribe"
msgstr ""

#: includes/forums/template.php:1170 includes/forums/template.php:2012
msgid "%s topic"
msgid_plural "%s topics"
msgstr[0] ""
msgstr[1] ""

#: includes/forums/template.php:1185 includes/topics/template.php:2026
msgid "(+%s hidden)"
msgid_plural "(+%s hidden)"
msgstr[0] ""
msgstr[1] ""

#: includes/forums/template.php:2001 includes/topics/template.php:2011
msgid "%s reply"
msgid_plural "%s replies"
msgstr[0] ""
msgstr[1] ""

#: includes/forums/template.php:2021
msgid "This category has %1$s, %2$s, and was last updated %3$s by %4$s."
msgstr ""

#: includes/forums/template.php:2022
msgid "This forum has %1$s, %2$s, and was last updated %3$s by %4$s."
msgstr ""

#: includes/forums/template.php:2027
msgid "This category has %1$s, and was last updated %2$s by %3$s."
msgstr ""

#: includes/forums/template.php:2028
msgid "This forum has %1$s, and was last updated %2$s by %3$s."
msgstr ""

#: includes/forums/template.php:2034
msgid "This category has %1$s and %2$s."
msgstr ""

#: includes/forums/template.php:2035
msgid "This forum has %1$s and %2$s."
msgstr ""

#: includes/forums/template.php:2040
msgid "This category has %1$s."
msgstr ""

#: includes/forums/template.php:2041
msgid "This forum has %1$s."
msgstr ""

#: includes/forums/template.php:2045
msgid "This forum is empty."
msgstr ""

#: includes/replies/functions.php:159
msgid "<strong>Error</strong>: You do not have permission to reply."
msgstr ""

#: includes/replies/functions.php:170
msgid "<strong>Error</strong>: Topic ID is missing."
msgstr ""

#: includes/replies/functions.php:174
msgid "<strong>Error</strong>: Topic ID must be a number."
msgstr ""

#: includes/replies/functions.php:184
msgid "<strong>Error</strong>: Topic ID cannot be a negative number."
msgstr ""

#: includes/replies/functions.php:188
msgid "<strong>Error</strong>: Topic does not exist."
msgstr ""

#: includes/replies/functions.php:207 includes/replies/functions.php:221
#: includes/topics/functions.php:187 includes/topics/functions.php:201
#: includes/topics/functions.php:498
msgid "<strong>Error</strong>: Forum ID is missing."
msgstr ""

#: includes/replies/functions.php:211 includes/topics/functions.php:191
msgid "<strong>Error</strong>: Forum ID must be a number."
msgstr ""

#: includes/replies/functions.php:225 includes/topics/functions.php:205
msgid "<strong>Error</strong>: Forum ID cannot be a negative number."
msgstr ""

#: includes/replies/functions.php:229 includes/topics/functions.php:209
msgid "<strong>Error</strong>: Forum does not exist."
msgstr ""

#: includes/replies/functions.php:243 includes/replies/functions.php:586
msgid ""
"<strong>Error</strong>: This forum is a category. No replies can be created "
"in this forum."
msgstr ""

#: includes/replies/functions.php:250 includes/replies/functions.php:593
msgid "<strong>Error</strong>: This forum has been closed to new replies."
msgstr ""

#: includes/replies/functions.php:255 includes/replies/functions.php:598
msgid ""
"<strong>Error</strong>: This forum is private and you do not have the "
"capability to read or create new replies in it."
msgstr ""

#: includes/replies/functions.php:259 includes/replies/functions.php:602
msgid ""
"<strong>Error</strong>: This forum is hidden and you do not have the "
"capability to read or create new replies in it."
msgstr ""

#: includes/replies/functions.php:298 includes/replies/functions.php:632
msgid "<strong>Error</strong>: Your reply cannot be empty."
msgstr ""

#: includes/replies/functions.php:318
msgid ""
"<strong>Error</strong>: Duplicate reply detected; it looks as though "
"you&#8217;ve already said that."
msgstr ""

#: includes/replies/functions.php:324
msgid "<strong>Error</strong>: Your reply cannot be created at this time."
msgstr ""

#: includes/replies/functions.php:348
msgid "<strong>Error</strong>: Topic is closed."
msgstr ""

#: includes/replies/functions.php:408 includes/replies/functions.php:738
msgid "<strong>Error</strong>: There was a problem adding the tags to the topic."
msgstr ""

#: includes/replies/functions.php:495
msgid "<strong>Error</strong>: The reply was not created."
msgstr ""

#: includes/replies/functions.php:523
msgid "<strong>Error</strong>: Reply ID not found."
msgstr ""

#: includes/replies/functions.php:540
msgid "<strong>Error</strong>: The reply you want to edit was not found."
msgstr ""

#: includes/replies/functions.php:551
msgid "<strong>Error</strong>: You do not have permission to edit that reply."
msgstr ""

#: includes/replies/functions.php:638
msgid "<strong>Error</strong>: Your reply cannot be edited at this time."
msgstr ""

#: includes/replies/functions.php:662 includes/replies/functions.php:1520
#: includes/topics/functions.php:291 includes/topics/functions.php:594
#: includes/topics/functions.php:2042
msgid "<strong>Error</strong>: You do not have permission to do that."
msgstr ""

#: includes/replies/functions.php:1239 includes/topics/functions.php:1360
msgid "<strong>Error</strong>: A reply ID is required."
msgstr ""

#: includes/replies/functions.php:1248
msgid "<strong>Error</strong>: The reply you want to move was not found."
msgstr ""

#: includes/replies/functions.php:1258
msgid "<strong>Error</strong>: The topic you want to move from was not found."
msgstr ""

#: includes/replies/functions.php:1269 includes/topics/functions.php:1120
#: includes/topics/functions.php:1390
msgid "<strong>Error</strong>: You do not have permission to edit the source topic."
msgstr ""

#: includes/replies/functions.php:1279
msgid "<strong>Error</strong>: You need to choose a valid move option."
msgstr ""

#: includes/replies/functions.php:1292 includes/topics/functions.php:1413
msgid "<strong>Error</strong>: A topic ID is required."
msgstr ""

#: includes/replies/functions.php:1302
msgid "<strong>Error</strong>: The topic you want to move to was not found."
msgstr ""

#: includes/replies/functions.php:1307 includes/topics/functions.php:1140
#: includes/topics/functions.php:1428
msgid ""
"<strong>Error</strong>: You do not have permission to edit the destination "
"topic."
msgstr ""

#: includes/replies/functions.php:1361 includes/topics/functions.php:1466
msgid ""
"<strong>Error</strong>: There was a problem converting the reply into the "
"topic. Please try again."
msgstr ""

#: includes/replies/functions.php:1366 includes/topics/functions.php:1471
msgid ""
"<strong>Error</strong>: You do not have permission to create new topics. "
"The reply could not be converted into a topic."
msgstr ""

#: includes/replies/functions.php:1514
msgid "<strong>Error</strong>: This reply could not be found or no longer exists."
msgstr ""

#: includes/replies/functions.php:1596
msgid "<strong>Error</strong>: There was a problem approving the reply."
msgstr ""

#: includes/replies/functions.php:1596
msgid "<strong>Error</strong>: There was a problem unapproving the reply."
msgstr ""

#: includes/replies/functions.php:1607
msgid "<strong>Error</strong>: There was a problem unmarking the reply as spam."
msgstr ""

#: includes/replies/functions.php:1607
msgid "<strong>Error</strong>: There was a problem marking the reply as spam."
msgstr ""

#: includes/replies/functions.php:1622
msgid "<strong>Error</strong>: There was a problem trashing the reply."
msgstr ""

#: includes/replies/functions.php:1630
msgid "<strong>Error</strong>: There was a problem untrashing the reply."
msgstr ""

#: includes/replies/functions.php:1638
msgid "<strong>Error</strong>: There was a problem deleting the reply."
msgstr ""

#: includes/replies/functions.php:2159
msgid "All Posts"
msgstr ""

#: includes/replies/functions.php:2205 includes/topics/functions.php:3818
msgid "Replies: %s"
msgstr ""

#: includes/replies/template.php:54
msgid "Create New Reply"
msgstr ""

#: includes/replies/template.php:56
msgid "Edit Reply"
msgstr ""

#: includes/replies/template.php:57
msgid "New Reply"
msgstr ""

#: includes/replies/template.php:58 includes/replies/template.php:59
msgid "View Reply"
msgstr ""

#: includes/replies/template.php:60
msgid "View Replies"
msgstr ""

#: includes/replies/template.php:61
msgid "Search Replies"
msgstr ""

#: includes/replies/template.php:62
msgid "No replies found"
msgstr ""

#: includes/replies/template.php:63
msgid "No replies found in Trash"
msgstr ""

#: includes/replies/template.php:64
msgid "Filter replies list"
msgstr ""

#: includes/replies/template.php:65
msgid "Replies list"
msgstr ""

#: includes/replies/template.php:66
msgid "Replies list navigation"
msgstr ""

#: includes/replies/template.php:67
msgid "Parent Topic:"
msgstr ""

#: includes/replies/template.php:68
msgid "Forum Replies"
msgstr ""

#: includes/replies/template.php:70
msgid "Insert into reply"
msgstr ""

#: includes/replies/template.php:71
msgid "Uploaded to this reply"
msgstr ""

#: includes/replies/template.php:72
msgid "Reply Image"
msgstr ""

#: includes/replies/template.php:73
msgid "Set reply image"
msgstr ""

#: includes/replies/template.php:74
msgid "Remove reply image"
msgstr ""

#: includes/replies/template.php:75
msgid "Use as reply image"
msgstr ""

#: includes/replies/template.php:76
msgid "Reply published."
msgstr ""

#: includes/replies/template.php:77
msgid "Reply published privately."
msgstr ""

#: includes/replies/template.php:78
msgid "Reply reverted to draft."
msgstr ""

#: includes/replies/template.php:79
msgid "Reply scheduled."
msgstr ""

#: includes/replies/template.php:552
#: templates/default/bbpress/form-reply.php:30
msgid "Reply To: %s"
msgstr ""

#: includes/replies/template.php:764
msgid "This reply was modified %1$s by %2$s. Reason: %3$s"
msgstr ""

#: includes/replies/template.php:766
msgid "This reply was modified %1$s by %2$s."
msgstr ""

#: includes/replies/template.php:1191 includes/topics/template.php:1424
#: includes/users/template.php:2037
msgid "View %s's profile"
msgstr ""

#: includes/replies/template.php:1192 includes/topics/template.php:1425
#: includes/users/template.php:2038
msgid "Visit %s's website"
msgstr ""

#: includes/replies/template.php:1649
#: templates/default/bbpress/form-user-passwords.php:31
msgid "Cancel"
msgstr ""

#: includes/replies/template.php:1959 includes/topics/template.php:2512
#: templates/default/bbpress/form-topic-tag.php:100
#: templates/default/bbpress/form-topic-tag.php:117
msgid "Delete"
msgstr ""

#: includes/replies/template.php:1984 includes/topics/template.php:2533
msgid "Are you sure you want to delete that permanently?"
msgstr ""

#: includes/replies/template.php:2081
msgid "Move"
msgstr ""

#: includes/replies/template.php:2082
msgid "Move this reply"
msgstr ""

#: includes/replies/template.php:2140
msgid "Split"
msgstr ""

#: includes/replies/template.php:2141
msgid "Split the topic from this reply"
msgstr ""

#: includes/replies/template.php:2375
msgid "Viewing %1$s reply thread"
msgid_plural "Viewing %1$s reply threads"
msgstr[0] ""
msgstr[1] ""

#: includes/replies/template.php:2382
msgid "Viewing %1$s reply"
msgid_plural "Viewing %1$s replies"
msgstr[0] ""
msgstr[1] ""

#: includes/replies/template.php:2386
msgid "Viewing %2$s replies (of %4$s total)"
msgid_plural "Viewing %1$s replies - %2$s through %3$s (of %4$s total)"
msgstr[0] ""
msgstr[1] ""

#: includes/replies/template.php:2394
msgid "Viewing %1$s post"
msgid_plural "Viewing %1$s posts"
msgstr[0] ""
msgstr[1] ""

#: includes/replies/template.php:2398
msgid "Viewing %2$s post (of %4$s total)"
msgid_plural "Viewing %1$s posts - %2$s through %3$s (of %4$s total)"
msgstr[0] ""
msgstr[1] ""

#: includes/search/template.php:176
msgid "Search Results for '%s'"
msgstr ""

#: includes/search/template.php:411
msgid "Viewing %1$s result"
msgid_plural "Viewing %1$s results"
msgstr[0] ""
msgstr[1] ""

#: includes/search/template.php:415
msgid "Viewing %2$s results (of %4$s total)"
msgid_plural "Viewing %1$s results - %2$s through %3$s (of %4$s total)"
msgstr[0] ""
msgstr[1] ""

#: includes/topics/functions.php:132
msgid "<strong>Error</strong>: You do not have permission to create new topics."
msgstr ""

#: includes/topics/functions.php:158 includes/topics/functions.php:545
msgid "<strong>Error</strong>: Your topic needs a title."
msgstr ""

#: includes/topics/functions.php:177 includes/topics/functions.php:564
msgid "<strong>Error</strong>: Your topic cannot be empty."
msgstr ""

#: includes/topics/functions.php:223
msgid ""
"<strong>Error</strong>: This forum is a category. No topics can be created "
"in this forum."
msgstr ""

#: includes/topics/functions.php:230 includes/topics/functions.php:520
msgid "<strong>Error</strong>: This forum has been closed to new topics."
msgstr ""

#: includes/topics/functions.php:235 includes/topics/functions.php:525
msgid ""
"<strong>Error</strong>: This forum is private and you do not have the "
"capability to read or create new topics in it."
msgstr ""

#: includes/topics/functions.php:239 includes/topics/functions.php:529
msgid ""
"<strong>Error</strong>: This forum is hidden and you do not have the "
"capability to read or create new topics in it."
msgstr ""

#: includes/topics/functions.php:261
msgid ""
"<strong>Error</strong>: Duplicate topic detected; it looks as though "
"you&#8217;ve already said that."
msgstr ""

#: includes/topics/functions.php:267
msgid "<strong>Error</strong>: Your topic cannot be created at this time."
msgstr ""

#: includes/topics/functions.php:419
msgid "<strong>Error</strong>: The topic was not created."
msgstr ""

#: includes/topics/functions.php:445 includes/topics/functions.php:1102
msgid "<strong>Error</strong>: Topic ID not found."
msgstr ""

#: includes/topics/functions.php:456
msgid "<strong>Error</strong>: The topic you want to edit was not found."
msgstr ""

#: includes/topics/functions.php:467
msgid "<strong>Error</strong>: You do not have permission to edit that topic."
msgstr ""

#: includes/topics/functions.php:513
msgid ""
"<strong>Error</strong>: This forum is a category. No topics can be created "
"in it."
msgstr ""

#: includes/topics/functions.php:570
msgid "<strong>Error</strong>: Your topic cannot be edited at this time."
msgstr ""

#: includes/topics/functions.php:1114
msgid "<strong>Error</strong>: The topic you want to merge was not found."
msgstr ""

#: includes/topics/functions.php:1128
msgid "<strong>Error</strong>: Destination topic ID not found."
msgstr ""

#: includes/topics/functions.php:1135
msgid "<strong>Error</strong>: The topic you want to merge to was not found."
msgstr ""

#: includes/topics/functions.php:1369
msgid "<strong>Error</strong>: The reply you want to split from was not found."
msgstr ""

#: includes/topics/functions.php:1379
msgid "<strong>Error</strong>: The topic you want to split was not found."
msgstr ""

#: includes/topics/functions.php:1400
msgid "<strong>Error</strong>: You need to choose a valid split option."
msgstr ""

#: includes/topics/functions.php:1423
msgid "<strong>Error</strong>: The topic you want to split to was not found."
msgstr ""

#: includes/topics/functions.php:1708
msgid ""
"<strong>Error</strong>: The following problem(s) have been found while "
"getting the tag: %s"
msgstr ""

#: includes/topics/functions.php:1726 includes/topics/functions.php:1770
msgid "<strong>Error</strong>: You do not have permission to edit the topic tags."
msgstr ""

#: includes/topics/functions.php:1732 includes/topics/functions.php:1776
msgid "<strong>Error</strong>: You need to enter a tag name."
msgstr ""

#: includes/topics/functions.php:1747
msgid ""
"<strong>Error</strong>: The following problem(s) have been found while "
"updating the tag: %s"
msgstr ""

#: includes/topics/functions.php:1787 includes/topics/functions.php:1808
msgid ""
"<strong>Error</strong>: The following problem(s) have been found while "
"merging the tags: %s"
msgstr ""

#: includes/topics/functions.php:1796
msgid "<strong>Error</strong>: The tags which are being merged can not be the same."
msgstr ""

#: includes/topics/functions.php:1831
msgid "<strong>Error</strong>: You do not have permission to delete the topic tags."
msgstr ""

#: includes/topics/functions.php:1840
msgid ""
"<strong>Error</strong>: The following problem(s) have been found while "
"deleting the tag: %s"
msgstr ""

#: includes/topics/functions.php:2036
msgid "<strong>Error</strong>: This topic could not be found or no longer exists."
msgstr ""

#: includes/topics/functions.php:2126
msgid "<strong>Error</strong>: There was a problem approving the topic."
msgstr ""

#: includes/topics/functions.php:2127
msgid "<strong>Error</strong>: There was a problem unapproving the topic."
msgstr ""

#: includes/topics/functions.php:2144
msgid "<strong>Error</strong>: There was a problem closing the topic."
msgstr ""

#: includes/topics/functions.php:2145
msgid "<strong>Error</strong>: There was a problem opening the topic."
msgstr ""

#: includes/topics/functions.php:2163
msgid "<strong>Error</strong>: There was a problem unsticking the topic."
msgstr ""

#: includes/topics/functions.php:2164
msgid "<strong>Error</strong>: There was a problem sticking the topic."
msgstr ""

#: includes/topics/functions.php:2182
msgid "<strong>Error</strong>: There was a problem unmarking the topic as spam."
msgstr ""

#: includes/topics/functions.php:2183
msgid "<strong>Error</strong>: There was a problem marking the topic as spam."
msgstr ""

#: includes/topics/functions.php:2196
msgid "<strong>Error</strong>: There was a problem trashing the topic."
msgstr ""

#: includes/topics/functions.php:2207
msgid "<strong>Error</strong>: There was a problem untrashing the topic."
msgstr ""

#: includes/topics/functions.php:2216
msgid "<strong>Error</strong>: There was a problem deleting the topic."
msgstr ""

#: includes/topics/template.php:52 templates/default/bbpress/form-topic.php:48
msgid "Create New Topic"
msgstr ""

#: includes/topics/template.php:54
msgid "Edit Topic"
msgstr ""

#: includes/topics/template.php:55
msgid "New Topic"
msgstr ""

#: includes/topics/template.php:56 includes/topics/template.php:57
msgid "View Topic"
msgstr ""

#: includes/topics/template.php:58
msgid "View Topics"
msgstr ""

#: includes/topics/template.php:59
msgid "Search Topics"
msgstr ""

#: includes/topics/template.php:60
msgid "No topics found"
msgstr ""

#: includes/topics/template.php:61
msgid "No topics found in Trash"
msgstr ""

#: includes/topics/template.php:62
msgid "Filter topics list"
msgstr ""

#: includes/topics/template.php:63
msgid "Topics list"
msgstr ""

#: includes/topics/template.php:64
msgid "Topics list navigation"
msgstr ""

#: includes/topics/template.php:66
msgid "Forum Topics"
msgstr ""

#: includes/topics/template.php:68
msgid "Insert into topic"
msgstr ""

#: includes/topics/template.php:69
msgid "Uploaded to this topic"
msgstr ""

#: includes/topics/template.php:70
msgid "Topic Image"
msgstr ""

#: includes/topics/template.php:71
msgid "Set topic image"
msgstr ""

#: includes/topics/template.php:72
msgid "Remove topic image"
msgstr ""

#: includes/topics/template.php:73
msgid "Use as topic image"
msgstr ""

#: includes/topics/template.php:74
msgid "Topic published."
msgstr ""

#: includes/topics/template.php:75
msgid "Topic published privately."
msgstr ""

#: includes/topics/template.php:76
msgid "Topic reverted to draft."
msgstr ""

#: includes/topics/template.php:77
msgid "Topic scheduled."
msgstr ""

#: includes/topics/template.php:928
msgid "This topic was modified %1$s by %2$s. Reason: %3$s"
msgstr ""

#: includes/topics/template.php:930
msgid "This topic was modified %1$s by %2$s."
msgstr ""

#: includes/topics/template.php:1824 includes/users/template.php:1113
msgid "Favorite"
msgstr ""

#: includes/topics/template.php:1825 includes/users/template.php:1114
msgid "Unfavorite"
msgstr ""

#: includes/topics/template.php:2190
msgid "Tagged:"
msgstr ""

#: includes/topics/template.php:2751
#: templates/default/bbpress/form-topic-tag.php:69
#: templates/default/bbpress/form-topic-tag.php:85
msgid "Merge"
msgstr ""

#: includes/topics/template.php:2990
msgid "Viewing %1$s topic"
msgid_plural "Viewing %1$s topics"
msgstr[0] ""
msgstr[1] ""

#: includes/topics/template.php:2994
msgid "Viewing topic %2$s (of %4$s total)"
msgid_plural "Viewing %1$s topics - %2$s through %3$s (of %4$s total)"
msgstr[0] ""
msgstr[1] ""

#: includes/topics/template.php:3051
msgid "This topic is marked as spam."
msgstr ""

#: includes/topics/template.php:3056
msgid "This topic is in the trash."
msgstr ""

#: includes/topics/template.php:3061 includes/topics/template.php:3329
msgid "This topic is pending moderation."
msgstr ""

#: includes/topics/template.php:3311
msgid "%s voice"
msgid_plural "%s voices"
msgstr[0] ""
msgstr[1] ""

#: includes/topics/template.php:3317
msgid "This topic has %1$s, %2$s, and was last updated %3$s by %4$s."
msgstr ""

#: includes/topics/template.php:3321
msgid "This topic has %1$s and %2$s."
msgstr ""

#: includes/topics/template.php:3325
msgid "This topic has no replies."
msgstr ""

#: includes/topics/template.php:3333
msgid "This topic is empty."
msgstr ""

#: includes/topics/template.php:3383
msgid "Search Tags"
msgstr ""

#: includes/topics/template.php:3384
msgid "Popular Tags"
msgstr ""

#: includes/topics/template.php:3385
msgid "All Tags"
msgstr ""

#: includes/topics/template.php:3386
msgid "Parent Tag"
msgstr ""

#: includes/topics/template.php:3387
msgid "Parent Tag:"
msgstr ""

#: includes/topics/template.php:3388
msgid "Edit Tag"
msgstr ""

#: includes/topics/template.php:3389
msgid "View Topic Tag"
msgstr ""

#: includes/topics/template.php:3390
msgid "Update Tag"
msgstr ""

#: includes/topics/template.php:3391
msgid "Add New Tag"
msgstr ""

#: includes/topics/template.php:3392
msgid "New Tag Name"
msgstr ""

#: includes/topics/template.php:3393
msgid "Separate topic tags with commas