/**
 * bbPress specific CSS
 *
 * @package bbPress
 * @subpackage Theme
 */

/* =bbPress Style
-------------------------------------------------------------- */

/* Hide completely (including from screen readers) */
.hidden,
.bbp-no-js .hide-if-no-js,
.bbp-js .hide-if-js {
	display: none;
}

/* Hide visually (but not from screen readers) */
.screen-reader-text,
.screen-reader-text span,
.ui-helper-hidden-accessible {
	position: absolute;
	margin: -1px;
	padding: 0;
	height: 1px;
	width: 1px;
	overflow: hidden;
	clip: rect(1px, 1px, 1px, 1px);
	-webkit-clip-path: inset(50%);
	clip-path: inset(50%);
	border: 0;
	word-wrap: normal !important; /* many screen reader and browser combinations announce broken words as they would appear visually */
}

#bbpress-forums {
	background: transparent;
	clear: both;
	margin-bottom: 20px;
	overflow: hidden;
	font-size: 12px;
	line-height: 18px;
}

#bbpress-forums a,
#bbpress-forums a:hover {
	box-shadow: none;
	border: none;
	transition: none;
}

/* Original UL styling */
#bbpress-forums ul,
/* Use ID & class together for increased target strength */
#bbpress-forums.bbpress-wrapper ul {
	background: none;
	list-style: none;
	margin: 0;
	padding: 0;
}

#bbpress-forums hr {
	margin: 0 0 24px;
}

#bbpress-forums div.even,
#bbpress-forums ul.even {
	background-color: #fff;
}

#bbpress-forums div.odd,
#bbpress-forums ul.odd {
	background-color: #fbfbfb;
}

body.reply-edit .reply {
	float: none;
}

#bbpress-forums div.reply {
	height: auto;
	width: 100%;
	box-sizing: border-box;
}

#bbpress-forums div.bbp-forum-header,
#bbpress-forums div.bbp-topic-header,
#bbpress-forums div.bbp-reply-header {
	background-color: #f4f4f4;
}

#bbpress-forums .status-trash.even,
#bbpress-forums .status-spam.even {
	background-color: #fee;
}

#bbpress-forums .status-trash.odd,
#bbpress-forums .status-spam.odd {
	background-color: #fdd;
}

#bbpress-forums .status-pending.even,
#bbpress-forums .status-pending.odd,
#bbpress-forums ul.status-pending a {
	background-color: #fef7f1;
}

#bbpress-forums ul.status-closed,
#bbpress-forums ul.status-closed a {
	color: #ccc;
}

#bbpress-forums ul.bbp-threaded-replies {
	margin-right: 50px;
}

#bbpress-forums li {
	background: none;
	margin: 0;
	list-style: none;
}

#bbpress-forums ul.bbp-lead-topic,
#bbpress-forums ul.bbp-topics,
#bbpress-forums ul.bbp-forums,
#bbpress-forums ul.bbp-replies,
#bbpress-forums ul.bbp-search-results {
	font-size: 12px;
	overflow: hidden;
	border: 1px solid #eee;
	margin-bottom: 20px;
	clear: both;
}

#bbpress-forums li.bbp-header,
#bbpress-forums li.bbp-body,
#bbpress-forums li.bbp-footer {
	clear: both;
}

#bbpress-forums li.bbp-header,
#bbpress-forums li.bbp-footer {
	background: #f3f3f3;
	border-top: 1px solid #eee;
	font-weight: 700;
	padding: 8px;
	text-align: center;
}

#bbpress-forums li.bbp-header {
	background: #eaeaea;
}

#bbpress-forums li.bbp-header ul {
	overflow: hidden;
}

#bbpress-forums .bbp-forums-list {
	margin: 0 7px 0 0;
	padding-right: 12px;
	border-right: 1px solid #ddd;
}

#bbpress-forums .bbp-forums-list .bbp-forum {
	display: inline;
	font-size: 11px;
}

#bbpress-forums .bbp-forums-list .bbp-forum.css-sep:not(:last-child)::after {
	content: ", ";
}

#bbpress-forums li.bbp-footer p {
	margin: 0;
	line-height: 1;
}

li.bbp-forum-info,
li.bbp-topic-title {
	float: right;
	text-align: right;
	width: 55%;
}

li.bbp-forum-topic-count,
li.bbp-topic-voice-count,
li.bbp-forum-reply-count,
li.bbp-topic-reply-count {
	float: right;
	text-align: center;
	width: 10%;
}

li.bbp-forum-freshness,
li.bbp-topic-freshness {
	text-align: center;
	float: right;
	width: 22%;
}

#bbpress-forums li.bbp-body ul.forum,
#bbpress-forums li.bbp-body ul.topic {
	border-top: 1px solid #eee;
	overflow: hidden;
	padding: 8px;
}

#bbpress-forums #subscription-toggle,
#bbpress-forums #favorite-toggle {
	float: left;
}

#bbpress-forums div.bbp-forum-title h3,
#bbpress-forums div.bbp-topic-title h3,
#bbpress-forums div.bbp-reply-title h3 {
	background: none;
	border: none;
	font-size: 16px;
	line-height: 1;
	margin: 8px 0;
	padding: 0;
	text-transform: none;
}

#bbpress-forums div.bbp-forum-author,
#bbpress-forums div.bbp-topic-author,
#bbpress-forums div.bbp-reply-author {
	float: right;
	text-align: center;
	width: 115px;
}

#bbpress-forums div.bbp-forum-author img.avatar,
#bbpress-forums div.bbp-topic-author img.avatar,
#bbpress-forums div.bbp-reply-author img.avatar {
	border: none;
	max-width: 80px;
	padding: 0;
	margin: 12px auto 0;
	float: none;
}

#bbpress-forums div.bbp-forum-author .bbp-author-name,
#bbpress-forums div.bbp-topic-author .bbp-author-name,
#bbpress-forums div.bbp-reply-author .bbp-author-name {
	margin: 0 12px;
	word-wrap: break-word;
	display: inline-block;
}

#bbpress-forums div.bbp-topic-author .bbp-author-name,
#bbpress-forums div.bbp-reply-author .bbp-author-name {
	clear: right;
	display: block;
}

#bbpress-forums div.bbp-forum-author .bbp-author-role,
#bbpress-forums div.bbp-topic-author .bbp-author-role,
#bbpress-forums div.bbp-reply-author .bbp-author-role {
	font-size: 11px;
	font-style: italic;
}

#bbpress-forums li.bbp-header .bbp-search-author,
#bbpress-forums li.bbp-footer .bbp-search-author,
#bbpress-forums li.bbp-header .bbp-forum-author,
#bbpress-forums li.bbp-footer .bbp-forum-author,
#bbpress-forums li.bbp-header .bbp-topic-author,
#bbpress-forums li.bbp-footer .bbp-topic-author,
#bbpress-forums li.bbp-header .bbp-reply-author,
#bbpress-forums li.bbp-footer .bbp-reply-author {
	float: right;
	margin: 0;
	padding: 0;
	width: 120px;
}

#bbpress-forums li.bbp-header .bbp-search-content,
#bbpress-forums li.bbp-footer .bbp-search-content,
#bbpress-forums li.bbp-header .bbp-forum-content,
#bbpress-forums li.bbp-footer .bbp-forum-content,
#bbpress-forums li.bbp-header .bbp-topic-content,
#bbpress-forums li.bbp-footer .bbp-topic-content,
#bbpress-forums li.bbp-header .bbp-reply-content,
#bbpress-forums li.bbp-footer .bbp-reply-content {
	margin-right: 140px;
	padding: 0;
	text-align: right;
}

div.bbp-forum-header,
div.bbp-topic-header,
div.bbp-reply-header,
li.bbp-body div.hentry {
	margin: 0;
	overflow: hidden;
	padding: 8px;
}

div.bbp-forum-header,
div.bbp-topic-header,
div.bbp-reply-header {
	border-top: 1px solid #ddd;
	clear: both;
}

span.bbp-author-ip {
	font-size: 11px;
	font-weight: 700;
	word-wrap: break-word;
	color: #747474;
}

/* =Topic and reply content
-------------------------------------------------------------- */

#bbpress-forums div.bbp-forum-content,
#bbpress-forums div.bbp-topic-content,
#bbpress-forums div.bbp-reply-content {
	margin-right: 130px;
	padding: 12px 0 12px 12px;
	text-align: right;
	position: relative;
}

/* Clearing hack */
#bbpress-forums div.bbp-forum-content::after,
#bbpress-forums div.bbp-topic-content::after,
#bbpress-forums div.bbp-reply-content::after {
	clear: both;
	content: ".";
	display: block;
	float: none;
	height: 0;
	font-size: 0;
	visibility: hidden;
}

#bbpress-forums div.bbp-topic-content a,
#bbpress-forums div.bbp-reply-content a {
	background: none;
	border: none;
	display: inline;
	font-weight: 400;
	margin: 0;
	padding: 0;
	text-decoration: underline;
}

#bbpress-forums div.bbp-topic-content a.bbp-user-mention,
#bbpress-forums div.bbp-reply-content a.bbp-user-mention {
	background: none;
	border: none;
	text-decoration: none;
	text-shadow: none;
	display: inline;
	font-weight: 600;
	margin: 0;
	padding: 0;
}

#bbpress-forums div.bbp-topic-content h1,
#bbpress-forums div.bbp-reply-content h1,
#bbpress-forums div.bbp-topic-content h2,
#bbpress-forums div.bbp-reply-content h2,
#bbpress-forums div.bbp-topic-content h3,
#bbpress-forums div.bbp-reply-content h3,
#bbpress-forums div.bbp-topic-content h4,
#bbpress-forums div.bbp-reply-content h4,
#bbpress-forums div.bbp-topic-content h5,
#bbpress-forums div.bbp-reply-content h5,
#bbpress-forums div.bbp-topic-content h6,
#bbpress-forums div.bbp-reply-content h6 {
	clear: none;
	line-height: 1;
	margin: 24px 0;
	padding: 0;
}

#bbpress-forums div.bbp-topic-content img,
#bbpress-forums div.bbp-reply-content img {
	max-width: 100%;
	height: auto;
}

#bbpress-forums div.bbp-topic-content ul,
#bbpress-forums div.bbp-reply-content ul,
#bbpress-forums div.bbp-topic-content ol,
#bbpress-forums div.bbp-reply-content ol {
	margin: 0 15px 15px;
	padding: 0;
}

#bbpress-forums div.bbp-topic-content ul li,
#bbpress-forums div.bbp-reply-content ul li {
	list-style-type: disc;
}

#bbpress-forums div.bbp-topic-content ol li,
#bbpress-forums div.bbp-reply-content ol li {
	list-style-type: decimal;
}

#bbpress-forums div.bbp-topic-content ol li li,
#bbpress-forums div.bbp-reply-content ol li li {
	list-style-type: lower-alpha;
}

#bbpress-forums div.bbp-topic-content ol li li li,
#bbpress-forums div.bbp-reply-content ol li li li {
	list-style-type: upper-roman;
}

#bbpress-forums div.bbp-topic-content code,
#bbpress-forums div.bbp-reply-content code,
#bbpress-forums div.bbp-topic-content pre,
#bbpress-forums div.bbp-reply-content pre {
	font-family: Inconsolata, Consolas, Monaco, "Lucida Console", monospace;
	display: inline-block;
	background-color: #f9f9f9;
	border: 1px solid #ddd;
	padding: 0 5px;
	max-width: 95%;
	vertical-align: middle;
	margin-top: -3px;
	overflow-x: auto;
}

#bbpress-forums div.bbp-topic-content pre,
#bbpress-forums div.bbp-reply-content pre {
	display: block;
	line-height: 18px;
	margin: 0 0 24px;
	padding: 5px 10px;
	white-space: pre;
	overflow: auto;
}

#bbpress-forums div.bbp-topic-content pre code,
#bbpress-forums div.bbp-reply-content pre code {
	display: block;
	border: none;
	padding: 0;
	margin: 0;
	background-color: transparent;
	overflow-wrap: normal;
	overflow: auto;
	max-width: 100%;
}

#bbpress-forums div.bbp-topic-content iframe.wp-embedded-content,
#bbpress-forums div.bbp-reply-content iframe.wp-embedded-content {
	position: relative;
}

/* =Reply to
-------------------------------------------------------------- */

#bbpress-forums div.bbp-reply-to {
	margin-right: 130px;
	padding: 12px 0 12px 12px;
	text-align: left;
}

#bbpress-forums div#bbp-cancel-reply-to {
	text-align: left;
}

/* =Breadcrumb and Tags
-------------------------------------------------------------- */

div.bbp-breadcrumb {
	float: right;
}

div.bbp-breadcrumb,
div.bbp-topic-tags {
	font-size: 12px;
}

#bbpress-forums div.bbp-breadcrumb p,
#bbpress-forums div.bbp-topic-tags p {
	margin: 0 0 10px 0;
}

#bbpress-forums div.bbp-topic-tags {
	float: left;
	clear: both;
}

#bbp-topic-hot-tags {
	clear: both;
}

/* =Search
-------------------------------------------------------------- */

#bbpress-forums #bbp-search-form {
	clear: right;
}

#bbpress-forums #bbp-search-form .hidden {
	height: 0;
	width: 0;
	overflow: hidden;
	position: absolute;
	background: none;
	right: -999em;
}

#bbpress-forums #bbp-search-form #bbp_search {
	display: inline-block;
	width: auto;
}

#bbpress-forums div.bbp-search-form {
	float: left;
}

/* =Admin Links
-------------------------------------------------------------- */

span.bbp-admin-links {
	float: left;
	color: #ddd;
}

span.bbp-admin-links a {
	color: #707070;
	font-weight: 400;
	font-size: 10px;
	text-transform: uppercase;
	text-decoration: none;
}

fieldset span.bbp-admin-links {
	float: right;
}

tr td span.bbp-admin-links a:hover {
	color: #ff4b33;
}

td.bbp-topic-admin-links,
td.bbp-topic-counts {
	width: 50%;
}

.bbp-forum-header a.bbp-forum-permalink,
.bbp-topic-header a.bbp-topic-permalink,
.bbp-reply-header a.bbp-reply-permalink {
	float: left;
	margin-right: 10px;
	color: #707070;
}

/* =Toggles
-------------------------------------------------------------- */

.bbp-row-actions #favorite-toggle a {
	text-decoration: none;
	padding: 0 3px 1px;
	color: #7c7;
	border: 1px solid #aca;
	background-color: #dfd;
	font-weight: 700;
	font-size: 12px;
}

.bbp-row-actions #favorite-toggle a:hover {
	color: #5a5;
	border-color: #7c7;
	background-color: #beb;
}

.bbp-row-actions #favorite-toggle span.is-favorite a {
	color: #faa;
	border: 1px solid #faa;
	background-color: #fee;
}

.bbp-row-actions #favorite-toggle span.is-favorite a:hover {
	color: #c88;
	border-color: #c88;
	background-color: #fdd;
}

.bbp-row-actions #subscription-toggle a {
	text-decoration: none;
	padding: 0 3px 1px;
	color: #7c7;
	border: 1px solid #aca;
	background-color: #dfd;
	font-weight: 700;
	font-size: 12px;
}

.bbp-row-actions #subscription-toggle a:hover {
	color: #5a5;
	border-color: #7c7;
	background-color: #beb;
}

.bbp-row-actions #subscription-toggle span.is-subscribed a {
	color: #faa;
	border: 1px solid #faa;
	background-color: #fee;
}

.bbp-row-actions #subscription-toggle span.is-subscribed a:hover {
	color: #c88;
	border-color: #c88;
	background-color: #fdd;
}

#bbpress-forums .bbp-forum-info .bbp-forum-content,
#bbpress-forums p.bbp-topic-meta {
	font-size: 11px;
	margin: 5px 0;
	padding: 0;
	word-wrap: break-word;
}

#bbpress-forums p.bbp-topic-meta span {
	white-space: nowrap;
}

/* =Pagination
-------------------------------------------------------------- */

.bbp-pagination-count {
	float: right;
	border: 1px solid transparent;
}

.bbp-pagination-links {
	float: left;
	list-style: none;
	display: inline;
}

.bbp-pagination {
	float: right;
	width: 100%;
	margin-bottom: 15px;
}

#bbpress-forums .bbp-pagination-links a,
#bbpress-forums .bbp-pagination-links span.current {
	display: block;
	float: right;
	font-size: 12px;
	line-height: 18px;
	padding: 0 5px;
	margin-right: 5px;
	border: 1px solid #efefef;
	border-radius: 0;
	background: transparent;
	color: inherit;
	text-decoration: none;
}

#bbpress-forums .bbp-pagination-links span.dots {
	display: block;
	float: right;
	padding: 1px 4px;
	margin-right: 5px;
}

#bbpress-forums .bbp-topic-pagination {
	display: inline-block;
	margin-right: 5px;
	margin-bottom: 2px;
}

#bbpress-forums .bbp-topic-pagination a {
	font-size: 10px;
	font-weight: 400;
	line-height: 10px;
	margin: 0;
	padding: 1px 3px;
	border: 1px solid #ddd;
	color: inherit;
	background: none;
	display: inline;
	text-decoration: none;
}

#bbpress-forums .bbp-topic-pagination a:hover,
#bbpress-forums .bbp-pagination-links a:hover,
#bbpress-forums .bbp-pagination-links span.current {
	background: #eee;
	opacity: 0.8;
	border: 1px solid #ddd;
}

/* =Forms
-------------------------------------------------------------- */

#bbpress-forums fieldset.bbp-form {
	clear: right;
	border: 1px solid #eee;
	padding: 10px 20px;
	margin-bottom: 10px;
}

#bbpress-forums fieldset.bbp-form legend {
	padding: 5px;
	width: auto;
	border: none;
}

#bbpress-forums fieldset.bbp-form label {
	margin: 0;
	display: inline-block;
}

#bbp-edit-topic-tag.bbp-form fieldset.bbp-form label,
#bbp-login fieldset label,
#bbp-register fieldset label,
#bbp-lost-pass fieldset label {
	width: 100px;
}

/* Some themes aggressively add padding to paragraph tags */
#bbpress-forums fieldset.bbp-form p {
	padding: 0;
}

#bbpress-forums fieldset.bbp-form p,
#bbpress-forums fieldset.bbp-form textarea,
#bbpress-forums fieldset.bbp-form select,
#bbpress-forums fieldset.bbp-form input {
	margin: 0 0 8px;
}

/* Try to prevent untall selects & text boxes */
#bbpress-forums fieldset.bbp-form select,
#bbpress-forums fieldset.bbp-form input[type="text"],
#bbpress-forums fieldset.bbp-form input[type="password"] {
	min-height: 28px;
	height: 28px;
	padding: 5px;
}

textarea#bbp_reply_content,
textarea#bbp_topic_content,
textarea#bbp_forum_content {
	width: 97%;
	box-sizing: border-box;
}

textarea#bbp_forum_content {
	height: 210px;
}

#bbpress-forums fieldset.bbp-forum-form-attributes {
	width: 200px;
	float: left;
	clear: none;
	margin-right: 25px;
}

/**
 * Fix for too-long forum names, usually from conversion
 */
#bbpress-forums fieldset select#bbp_forum_id {
	max-width: 200px;
}

.bbp-topic-form,
.bbp-reply-form,
.bbp-topic-tag-form {
	clear: right;
}

body.topic-edit .bbp-topic-form div.avatar img,
body.reply-edit .bbp-reply-form div.avatar img,
body.single-forum .bbp-topic-form div.avatar img,
body.single-reply .bbp-reply-form div.avatar img {
	margin-left: 0;
	padding: 10px;
	border: 1px solid #ddd;
	line-height: 0;
	background-color: #efefef;
}

body.page .bbp-reply-form code,
body.page .bbp-topic-form code,
body.single-topic .bbp-reply-form code,
body.single-forum .bbp-topic-form code,
body.topic-edit .bbp-topic-form code,
body.reply-edit .bbp-reply-form code {
	font-size: 10px;
	background-color: #f0fff8;
	border: 1px solid #ceefe1;
	display: block;
	padding: 8px;
	margin-top: 5px;
	width: 369px;
}

#merge_tag,
#delete_tag {
	display: inline;
}

div.bbp-submit-wrapper {
	margin-top: 15px;
	float: left;
	clear: both;
}

p.form-allowed-tags {
	max-width: 100%;
}

/* =TinyMCE in themes
-------------------------------------------------------------- */
#bbpress-forums div.bbp-the-content-wrapper {
	margin-bottom: 10px;
}

#bbpress-forums div.bbp-the-content-wrapper textarea.bbp-the-content {
	width: 100%;
	margin: 0;
	font-size: 12px;
}

#bbpress-forums div.bbp-the-content-wrapper table,
#bbpress-forums div.bbp-the-content-wrapper tbody,
#bbpress-forums div.bbp-the-content-wrapper tr,
#bbpress-forums div.bbp-the-content-wrapper td {
	border: none;
	padding: 0;
	margin: 0;
	width: auto;
	line-height: 1;
}

#bbpress-forums div.bbp-the-content-wrapper input[type="button"] {
	padding: 4px 7px;
	margin: 0 0 0 -1px;
	line-height: 0;
	border: 1px solid transparent;
	background-color: transparent;
	box-shadow: none;
	text-shadow: none;
	text-transform: uppercase;
	font-size: 11px;
	font-weight: 400;
	border-radius: 3px;
	min-width: 25px;
	color: #555;
}

#bbpress-forums div.bbp-the-content-wrapper input[type="button"]:hover {
	border-color: rgba(0, 0, 0, 0.1);
	background-color: rgba(255, 255, 255, 0.5);
}

#bbpress-forums div.bbp-the-content-wrapper div.quicktags-toolbar {
	padding: 5px;
	min-height: 26px;
}

#bbpress-forums div.bbp-the-content-wrapper td.mceToolbar {
	padding: 4px 4px 8px;
}

#bbpress-forums div.wp-editor-container {
	margin: 0;
	padding: 0;
	line-height: 0;
}

#bbpress-forums div.bbp-the-content-wrapper td.mceStatusbar {
	line-height: 16px;
}

#bbpress-forums .bbp-replies .bbp-reply-form {
	margin: 0 10px 0 10px;
}

/* =Edit User
-------------------------------------------------------------- */

#bbpress-forums #bbp-your-profile fieldset {
	padding: 20px 20px 0;
}

#bbpress-forums #bbp-your-profile fieldset div {
	margin-bottom: 20px;
	float: right;
	width: 100%;
	clear: right;
}

#bbpress-forums #bbp-your-profile fieldset select {
	margin-bottom: 0;
	width: 60%;
	background-color: #f9f9f9;
	border: 1px solid #ddd;
}

#bbpress-forums #bbp-your-profile fieldset input,
#bbpress-forums #bbp-your-profile fieldset textarea {
	margin-bottom: 0;
	width: 60%;
	background-color: #f9f9f9;
	border: 1px solid #ddd;
	box-shadow: none;
	border-radius: 0;
}

#bbpress-forums #bbp-your-profile fieldset input:focus,
#bbpress-forums #bbp-your-profile fieldset textarea:focus {
	border: 1px solid #ccc;
	box-shadow: inset -1px 1px 1px rgba(0, 0, 0, 0.1);
	outline-color: rgba(240, 255, 240, 0.1);
}

#bbpress-forums #bbp-your-profile fieldset.bbp-form input.checkbox {
	width: auto;
}

#bbpress-forums #bbp-your-profile fieldset legend {
	display: none;
}

#bbpress-forums #bbp-your-profile fieldset label[for] {
	float: right;
	width: 20%;
	padding: 5px 0 5px 20px;
	text-align: left;
	cursor: pointer;
}

#bbpress-forums #bbp-your-profile fieldset dl label[for] {
	text-align: right;
	width: 60%;
}

#bbpress-forums #bbp-your-profile fieldset p.description {
	margin: 5px 20% 0 0;
	font-size: 12px;
	font-style: italic;
	float: right;
	clear: right;
	width: 60%;
	padding: 5px 8px;
	border: #cee1ef 1px solid;
	background-color: #f0f8ff;
}

#bbpress-forums #bbp-your-profile fieldset fieldset {
	margin: 0;
	border: none;
	padding: 0;
	clear: none;
	float: none;
}

#bbpress-forums #bbp-your-profile fieldset fieldset.capabilities dl {
	margin: 0;
}

#bbpress-forums #bbp-your-profile fieldset.submit button {
	float: left;
}

/* =Password Generator
-------------------------------------------------------------- */

#bbpress-forums #bbp-your-profile fieldset fieldset.password {
	width: 60%;
	margin-right: 20%;
	margin-top: 10px;
}

#bbpress-forums #bbp-your-profile fieldset fieldset.password .password-input-wrapper,
#bbpress-forums #bbp-your-profile fieldset fieldset.password .password-button-wrapper {
	width: 100%;
	margin: 0;
	display: inline-block;
}

#bbpress-forums #bbp-your-profile fieldset fieldset.password .password-button-wrapper button {
	width: 46%;
	margin: 4% 2%;
	box-sizing: border-box;
	display: inline-block;
}

#bbpress-forums #bbp-your-profile fieldset fieldset.password input,
#bbpress-forums #bbp-your-profile fieldset fieldset.passwword textarea {
	width: 100%;
}

#bbpress-forums #bbp-your-profile fieldset fieldset.password button .dashicons {
	display: none;
}

#bbpress-forums #bbp-your-profile fieldset fieldset.password span.description {
	margin-right: 0;
	margin-bottom: 20px;
}

#bbpress-forums #password #pass-strength-result {
	background-color: #eee;
	border: 1px solid #ddd;
	color: #23282d;
	margin: 0;
	padding: 8px;
	text-align: center;
	box-sizing: border-box;
	display: inline-block;
}

#bbpress-forums #password #pass-strength-result.short {
	background-color: #f1adad;
	border-color: #e35b5b;
	opacity: 1;
}

#bbpress-forums #password #pass-strength-result.bad {
	background-color: #fbc5a9;
	border-color: #f78b53;
	opacity: 1;
}

#bbpress-forums #password #pass-strength-result.good {
	background-color: #ffe399;
	border-color: #ffc733;
	opacity: 1;
}

#bbpress-forums #password #pass-strength-result.strong {
	background-color: #c1e1b9;
	border-color: #83c373;
	opacity: 1;
}

#bbpress-forums #password #pass1.short,
#bbpress-forums #password #pass1-text.short {
	border-color: #e35b5b;
}

#bbpress-forums #password #pass1.bad,
#bbpress-forums #password #pass1-text.bad {
	border-color: #f78b53;
}

#bbpress-forums #password #pass1.good,
#bbpress-forums #password #pass1-text.good {
	border-color: #ffc733;
}

#bbpress-forums #password #pass1.strong,
#bbpress-forums #password #pass1-text.strong {
	border-color: #83c373;
}

#bbpress-forums .indicator-hint {
	padding-top: 8px;
}

#bbpress-forums .pw-weak,
#bbpress-forums #pass1-text,
#bbpress-forums .show-password #pass1 {
	display: none;
}

#bbpress-forums .show-password #pass1-text {
	display: inline-block;
}

/* =Notices
-------------------------------------------------------------- */

div.bbp-template-notice,
div.indicator-hint {
	border-width: 1px;
	border-style: solid;
	padding: 0 0.6em;
	margin: 5px 0 15px;
	border-radius: 3px;
	background-color: #ffffe0;
	border-color: #e6db55;
	color: #000;
	clear: both;
}

div.bbp-template-notice a {
	color: #555;
	text-decoration: none;

}

div.bbp-template-notice a:hover {
	color: #000;
}

div.bbp-template-notice.info {
	border: #cee1ef 1px solid;
	background-color: #f0f8ff;
}

div.bbp-template-notice.important {
	border: #e6db55 1px solid;
	background-color: #fffbcc;
}

div.bbp-template-notice.error,
div.bbp-template-notice.warning {
	background-color: #ffebe8;
	border-color: #c00;
}

div.bbp-template-notice.error a,
div.bbp-template-notice.warning a {
	color: #c00;
}

div.bbp-template-notice p,
div.bbp-template-notice li {
	margin: 0.5em 0 6px !important;
	padding: 2px;
	font-size: 12px;
	line-height: 1.4;
}

#bbpress-forums div.bbp-template-notice code {
	font-size: 11px;
	padding: 2px 4px;
	background: rgba(200, 200, 200, 0.3);
	border-radius: 3px;
}

/* =Stickies
-------------------------------------------------------------- */

.bbp-topics-front ul.super-sticky,
.bbp-topics ul.super-sticky,
.bbp-topics ul.sticky,
.bbp-forum-content ul.sticky {
	background-color: #ffffe0 !important;
	font-size: 1.1em;
}

/* =Revisions
-------------------------------------------------------------- */

#bbpress-forums .bbp-topic-content ul.bbp-topic-revision-log,
#bbpress-forums .bbp-reply-content ul.bbp-topic-revision-log,
#bbpress-forums .bbp-reply-content ul.bbp-reply-revision-log {
	border-top: 1px dotted #ddd;
	width: 100%;
	margin: 0;
	padding: 8px 0 0;
	font-size: 11px;
	color: #aaa;
}

#bbpress-forums .bbp-topic-content ul.bbp-topic-revision-log li,
#bbpress-forums .bbp-reply-content ul.bbp-topic-revision-log li,
#bbpress-forums .bbp-reply-content ul.bbp-reply-revision-log li {
	list-style-type: none;
}

#bbpress-forums .bbp-topic-content ul.bbp-topic-revision-log a,
#bbpress-forums .bbp-reply-content ul.bbp-topic-revision-log a,
#bbpress-forums .bbp-reply-content ul.bbp-reply-revision-log a {
	text-decoration: none;
}

/* =Widgets
-------------------------------------------------------------- */

.bbp-login-form fieldset legend {
	display: none;
}

.bbp-login-form .bbp-username input,
.bbp-login-form .bbp-email input,
.bbp-login-form .bbp-password input {
	padding: 5px;
}

.bbp-login-form label {
	width: 140px;
	display: inline-block;
}

#sidebar .bbp-login-form label {
	width: 70px;
}

.bbp-login-form .bbp-username,
.bbp-login-form .bbp-email,
.bbp-login-form .bbp-password,
.bbp-login-form .bbp-remember-me,
.bbp-login-form .bbp-submit-wrapper {
	margin-top: 10px;
}

.bbp-login-form .bbp-submit-wrapper {
	text-align: left;
}

.bbp-login-form .bbp-login-links a {
	float: right;
	clear: right;
}

.bbp-logged-in img.avatar {
	float: right;
	margin: 0 0 0 15px;
}

.bbp-logged-in h4 {
	font-weight: 700;
	font-size: 1.3em;
	clear: none;
	margin-bottom: 10px;
}

/* =Avatars
-------------------------------------------------------------- */

#bbpress-forums img.avatar {
	box-shadow: none;
	display: inline-block;
	margin-left: 4px;
}

#bbpress-forums p.bbp-topic-meta img.avatar,
#bbpress-forums ul.bbp-reply-revision-log img.avatar,
#bbpress-forums ul.bbp-topic-revision-log img.avatar,
#bbpress-forums div.bbp-template-notice img.avatar,
#bbpress-forums .widget_display_topics img.avatar,
#bbpress-forums .widget_display_replies img.avatar {
	float: none;
	vertical-align: middle;
	border: 3px double #ddd;
	max-height: 20px;
	max-width: 20px;
}

fieldset div.avatar {
	float: left;
}

/* =BuddyPress Activity Streams
-------------------------------------------------------------- */

.activity-list li.bbp_topic_create .activity-content .activity-inner,
.activity-list li.bbp_reply_create .activity-content .activity-inner {
	border-right: 2px solid #eaeaea;
	margin-right: 5px;
	padding-right: 10px;
}

/* =User Pages
-------------------------------------------------------------- */

#bbpress-forums h1 {
	clear: none;
	font-size: 1.8em;
	line-height: 1;
	padding-bottom: 10px;
}

#bbpress-forums #bbp-user-wrapper {
	float: right;
	width: 100%;
}

#bbpress-forums .bbp-user-section {
	overflow: auto;
	clear: left;
}

#bbpress-forums #bbp-user-wrapper h2.entry-title {
	font-size: 1.4em;
	margin: 0;
	padding-bottom: 10px;
	padding-top: 0;
	clear: none;
}

#bbpress-forums #bbp-user-wrapper ul.bbp-lead-topic,
#bbpress-forums #bbp-user-wrapper ul.bbp-topics,
#bbpress-forums #bbp-user-wrapper ul.bbp-forums,
#bbpress-forums #bbp-user-wrapper ul.bbp-replies,
#bbpress-forums #bbp-user-wrapper fieldset.bbp-form {
	clear: none;
}

#bbpress-forums #bbp-single-user-details {
	margin: 0;
	width: 150px;
	float: right;
	overflow: hidden;
}

#bbpress-forums #bbp-single-user-details #bbp-user-avatar {
	margin: 0;
	width: 150px;
}

#bbpress-forums #bbp-single-user-details #bbp-user-avatar img.avatar {
	border: none;
	height: 150px;
	padding: 0;
	margin: 0 0 20px;
	width: 150px;
}

#bbpress-forums #bbp-single-user-details #bbp-user-description {
	float: none;
	margin-right: 180px;
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation {
	float: none;
	margin: 0;
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation li {
	margin: 0;
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation a {
	padding: 5px 8px;
	display: block;
	border: 1px solid transparent;
	text-decoration: none;
}

#bbpress-forums #bbp-single-user-details #bbp-user-navigation li.current a {
	background: #eee;
	opacity: 0.8;
}

#bbpress-forums #bbp-user-body {
	margin-right: 180px;
}

body.my-account #bbpress-forums {
	border-top: none;
	padding-top: 0;
	margin-bottom: 0;
}

/* =User Capabilities
-------------------------------------------------------------- */

#bbpress-forums dl.bbp-user-capabilities {
	display: inline-block;
	vertical-align: top;
}

#bbpress-forums dl.bbp-user-capabilities dt {
	margin: 0 0 10px;
	text-transform: capitalize;
}

#bbpress-forums dl.bbp-user-capabilities dd {
	margin: 0;
	padding: 0;
}

/* =Alerts
-------------------------------------------------------------- */

.bbp-alert-outer {
	height: 100%;
	width: 100%;
	top: 0;
	right: 0;
	position: fixed;
	background-color: rgba(0, 0, 0, 0.2);
	z-index: 99999;
}

.bbp-alert-inner {
	width: 350px;
	text-align: center;
	background: #fff;
	position: fixed;
	top: 50%;
	right: 50%;
	margin-top: -75px;
	margin-right: -185px;
	border-radius: 3px;
	border: 1px solid #aaa;
	padding: 15px 10px 10px;
}

.bbp-alert-outer .bbp-alert-inner p {
	margin: 10px 0;
}

.bbp-alert-actions a {
	padding: 5px 20px;
	text-decoration: none;
}

/*--------------------------------------------------------------
 Media Queries
--------------------------------------------------------------*/

/* =Standard Mobile Landscape
-------------------------------------------------------------- */
@media only screen and (max-width: 480px) {

	#bbpress-forums div.bbp-topic-tags {
		clear: both;
		float: none;
	}

	div.bbp-search-form input,
	div.bbp-search-form button {
		font-size: 11px;
		padding: 2px;
	}

	li.bbp-forum-info,
	li.bbp-topic-title {
		width: 45%;
	}

	li.bbp-forum-topic-count,
	li.bbp-forum-reply-count,
	li.bbp-topic-voice-count,
	li.bbp-topic-reply-count {
		width: 15%;
	}

	span.bbp-topic-post-date,
	span.bbp-reply-post-date {
		float: right;
	}

	span.bbp-admin-links {
		float: none;
		clear: both;
	}

	#bbpress-forums .bbp-forums-list li,
	#bbpress-forums .bbp-forums-list span {
		display: block;
		font-size: 11px;
	}

	#bbpress-forums .bbp-body div.bbp-topic-author,
	#bbpress-forums .bbp-body div.bbp-reply-author {
		float: none;
		margin: 10px;
		min-height: 80px;
		padding-right: 80px;
		position: relative;
		text-align: right;
		width: calc(100% - 100px);
		border-bottom: 1px solid #efefef;
		box-sizing: content-box;
	}

	#bbpress-forums div.bbp-topic-author .bbp-author-name,
	#bbpress-forums div.bbp-reply-author .bbp-author-name {
		clear: none;
		display: inline-block;
		margin-right: 0;
		word-wrap: break-word;
	}

	#bbpress-forums div.bbp-topic-author img.avatar,
	#bbpress-forums div.bbp-reply-author img.avatar {
		position: absolute;
		top: 0;
		right: 0;
		width: 60px;
		height: auto;
		margin-top: 0;
	}

	#bbpress-forums div.bbp-topic-author .bbp-author-role,
	#bbpress-forums div.bbp-reply-author .bbp-author-role {
		font-size: 12px;
		font-style: normal;
	}

	#bbpress-forums .bbp-body div.bbp-topic-content,
	#bbpress-forums .bbp-body div.bbp-reply-content {
		clear: both;
		margin: 0 10px 5px 10px;
		padding: 0;
	}

	#bbpress-forums div.bbp-topic-content p,
	#bbpress-forums div.bbp-reply-content p {
		margin-bottom: 1em;
	}

	#bbpress-forums div.bbp-topic-content p:last-child,
	#bbpress-forums div.bbp-reply-content p:last-child {
		margin-bottom: 0;
	}

	div.bbp-submit-wrapper {
		float: right;
	}

	#bbpress-forums fieldset.bbp-form {
		padding: 0 10px 10px;
	}

	#bbpress-forums #bbp-user-body {
		clear: both;
		margin-right: 0;
		word-wrap: break-word;
	}

	#bbpress-forums div.bbp-forum-title h3,
	#bbpress-forums div.bbp-topic-title h3,
	#bbpress-forums div.bbp-reply-title h3 {
		font-size: 14px;
	}
}

/* =Standard Mobile Portrait
-------------------------------------------------------------- */
@media only screen and (max-width: 320px) {

	#bbpress-forums div.bbp-search-form {
		margin-bottom: 10px;
	}

	#bbpress-forums li.bbp-header li.bbp-forum-info,
	#bbpress-forums li.bbp-body li.bbp-forum-info,
	#bbpress-forums li.bbp-header li.bbp-topic-title,
	#bbpress-forums li.bbp-body li.bbp-topic-title {
		width: 100%;
	}

	#bbpress-forums li.bbp-header li.bbp-forum-info,
	#bbpress-forums li.bbp-header li.bbp-topic-title {
		text-align: center;
		text-transform: uppercase;
	}

	#bbpress-forums li.bbp-header li.bbp-forum-topic-count,
	#bbpress-forums li.bbp-header li.bbp-forum-reply-count,
	#bbpress-forums li.bbp-body li.bbp-forum-topic-count,
	#bbpress-forums li.bbp-body li.bbp-forum-reply-count,
	#bbpress-forums li.bbp-header li.bbp-topic-voice-count,
	#bbpress-forums li.bbp-header li.bbp-topic-reply-count,
	#bbpress-forums li.bbp-body li.bbp-topic-voice-count,
	#bbpress-forums li.bbp-body li.bbp-topic-reply-count {
		width: 20%;
	}

	#bbpress-forums li.bbp-header li.bbp-forum-freshness,
	#bbpress-forums li.bbp-body li.bbp-forum-freshness,
	#bbpress-forums li.bbp-header li.bbp-topic-freshness,
	#bbpress-forums li.bbp-body li.bbp-topic-freshness {
		width: 58%;
	}

	#bbpress-forums li.bbp-body li.bbp-forum-topic-count,
	#bbpress-forums li.bbp-body li.bbp-forum-reply-count,
	#bbpress-forums li.bbp-body li.bbp-forum-freshness,
	#bbpress-forums li.bbp-body li.bbp-topic-voice-count,
	#bbpress-forums li.bbp-body li.bbp-topic-reply-count,
	#bbpress-forums li.bbp-body li.bbp-topic-freshness {
		margin-top: 7px;
	}

	#bbpress-forums li.bbp-header,
	#bbpress-forums li.bbp-footer {
		font-size: 10px;
	}

	#bbpress-forums li.bbp-header div.bbp-search-author,
	#bbpress-forums li.bbp-header div.bbp-topic-author,
	#bbpress-forums li.bbp-header div.bbp-reply-author {
		text-align: right;
		width: 25%;
	}

	#bbpress-forums li.bbp-header div.bbp-search-content,
	#bbpress-forums li.bbp-header div.bbp-topic-content,
	#bbpress-forums li.bbp-header div.bbp-reply-content {
		margin-right: 25%;
	}

	#bbpress-forums div.bbp-template-notice img.avatar,
	#bbpress-forums p.bbp-topic-meta img.avatar {
		width: 14px;
		height: auto;
		max-height: 14px;
		max-width: 14px;
	}

	#bbpress-forums div.bbp-the-content-wrapper td.mceToolbar {
		padding: 1px;
	}

	#bbpress-forums div.bbp-the-content-wrapper td.mceToolbar td {
		width: 20px;
		height: 20px;
	}

	#bbpress-forums div.wp-editor-container {
		width: 100%;
		overflow: auto;
	}

	#bbpress-forums input#bbp_topic_title,
	#bbpress-forums input#bbp_topic_tags {
		width: 95%;
	}

	#bbpress-forums div.bbp-forum-title h3,
	#bbpress-forums div.bbp-topic-title h3,
	#bbpress-forums div.bbp-reply-title h3 {
		font-size: 14px;
	}
}

/* =Extra Small Mobile
-------------------------------------------------------------- */
@media only screen and (max-width: 240px) {

	#bbpress-forums li.bbp-header li.bbp-forum-topic-count,
	#bbpress-forums li.bbp-header li.bbp-forum-reply-count,
	#bbpress-forums li.bbp-body li.bbp-forum-topic-count,
	#bbpress-forums li.bbp-body li.bbp-forum-reply-count,
	#bbpress-forums li.bbp-header li.bbp-topic-voice-count,
	#bbpress-forums li.bbp-header li.bbp-topic-reply-count,
	#bbpress-forums li.bbp-body li.bbp-topic-voice-count,
	#bbpress-forums li.bbp-body li.bbp-topic-reply-count,
	#bbpress-forums li.bbp-footer div.bbp-search-author,
	#bbpress-forums li.bbp-footer div.bbp-topic-author,
	#bbpress-forums li.bbp-footer div.bbp-reply-author {
		width: 45%;
	}

	#bbpress-forums li.bbp-header li.bbp-forum-freshness,
	#bbpress-forums li.bbp-body li.bbp-forum-freshness,
	#bbpress-forums li.bbp-header li.bbp-topic-freshness,
	#bbpress-forums li.bbp-body li.bbp-topic-freshness {
		clear: both;
		width: 100%;
	}

	#bbpress-forums li.bbp-header li.bbp-forum-freshness,
	#bbpress-forums li.bbp-header li.bbp-topic-freshness {
		text-align: center;
	}

	#bbpress-forums li.bbp-body li.bbp-topic-freshness,
	#bbpress-forums li.bbp-header div.bbp-search-author,
	#bbpress-forums li.bbp-header div.bbp-search-content,
	#bbpress-forums li.bbp-header div.bbp-topic-author,
	#bbpress-forums li.bbp-header div.bbp-topic-content,
	#bbpress-forums li.bbp-header div.bbp-reply-author,
	#bbpress-forums li.bbp-header div.bbp-reply-content {
		margin-right: 0;
		text-align: right;
	}

	#bbpress-forums li.bbp-body li.bbp-topic-freshness p.bbp-topic-meta {
		display: inline-block;
	}

	#bbpress-forums li.bbp-header {
		overflow: hidden;
	}

	#bbpress-forums li.bbp-footer div.bbp-search-content,
	#bbpress-forums li.bbp-footer div.bbp-topic-content,
	#bbpress-forums li.bbp-footer div.bbp-reply-content {
		display: inline-block;
		margin-right: 0;
	}

	#bbpress-forums li.bbp-body div.bbp-topic-author,
	#bbpress-forums li.bbp-body div.bbp-reply-author {
		min-height: 60px;
		padding-right: 60px;
	}

	#bbpress-forums div.bbp-topic-author img.avatar,
	#bbpress-forums div.bbp-reply-author img.avatar {
		width: 40px;
		height: auto;
	}

	#bbpress-forums div.bbp-forum-title h3,
	#bbpress-forums div.bbp-topic-title h3,
	#bbpress-forums div.bbp-reply-title h3 {
		font-size: 12px;
	}
}
